@@ -14,8 +14,6 @@
 #  along with this program; if not, write to the Free Software Foundation,
 #  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #
-# Contributor(s): Campbell Barton
-#
 # ##### END GPL LICENSE BLOCK #####
 
 # <pep8 compliant>
@@ -73,6 +71,8 @@ def rna_info_BuildRNAInfo_cache():
     if rna_info_BuildRNAInfo_cache.ret is None:
         rna_info_BuildRNAInfo_cache.ret = rna_info.BuildRNAInfo()
     return rna_info_BuildRNAInfo_cache.ret
+
+
 rna_info_BuildRNAInfo_cache.ret = None
 # --- end rna_info cache
 
@@ -133,22 +133,6 @@ def handle_args():
                         help="Path of the API docs (default=<script dir>)",
                         required=False)
 
-    parser.add_argument("-T", "--sphinx-theme",
-                        dest="sphinx_theme",
-                        type=str,
-                        default="classic",
-                        help="Sphinx theme (default='classic'), "
-                        "see: http://sphinx-doc.org/theming.html",
-                        required=False)
-
-    parser.add_argument("-N", "--sphinx-named-output",
-                        dest="sphinx_named_output",
-                        default=False,
-                        action='store_true',
-                        help="Add the theme name to the html dir name.\n"
-                             "Example: \"sphinx-out_haiku\" (default=False)",
-                        required=False)
-
     parser.add_argument("-B", "--sphinx-build",
                         dest="sphinx_build",
                         default=False,
@@ -229,14 +213,6 @@ else:
     EXCLUDE_INFO_DOCS = True
     EXCLUDE_MODULES = [
         "aud",
-        "bge",
-        "bge.app"
-        "bge.constraints",
-        "bge.events",
-        "bge.logic",
-        "bge.render",
-        "bge.texture",
-        "bge.types",
         "bgl",
         "blf",
         "bmesh",
@@ -246,6 +222,7 @@ else:
         "bmesh.geometry",
         "bpy.app",
         "bpy.app.handlers",
+        "bpy.app.timers",
         "bpy.app.translations",
         "bpy.context",
         "bpy.data",
@@ -257,7 +234,10 @@ else:
         "bpy.utils.previews",
         "bpy_extras",
         "gpu",
-        "gpu.offscreen",
+        "gpu.types",
+        "gpu.matrix",
+        "gpu.select",
+        "gpu_extras",
         "idprop.types",
         "mathutils",
         "mathutils.bvhtree",
@@ -332,17 +312,14 @@ except ImportError:
 # to avoid having to match Blender's source tree.
 EXTRA_SOURCE_FILES = (
     "../../../release/scripts/templates_py/bmesh_simple.py",
+    "../../../release/scripts/templates_py/gizmo_operator.py",
+    "../../../release/scripts/templates_py/gizmo_operator_target.py",
+    "../../../release/scripts/templates_py/gizmo_simple.py",
     "../../../release/scripts/templates_py/operator_simple.py",
     "../../../release/scripts/templates_py/ui_panel_simple.py",
     "../../../release/scripts/templates_py/ui_previews_custom_icon.py",
-    "../examples/bge.constraints.py",
-    "../examples/bge.texture.1.py",
-    "../examples/bge.texture.2.py",
-    "../examples/bge.texture.py",
     "../examples/bmesh.ops.1.py",
     "../examples/bpy.app.translations.py",
-    "../static/favicon.ico",
-    "../static/blender_logo.svg",
 )
 
 
@@ -361,23 +338,24 @@ RST_DIR = os.path.abspath(os.path.join(SCRIPT_DIR, "rst"))
 # stored in ./rst/info_*
 INFO_DOCS = (
     ("info_quickstart.rst",
-     "Blender/Python Quickstart: new to Blender/scripting and want to get your feet wet?"),
+     "Quickstart: new to Blender or scripting and want to get your feet wet?"),
     ("info_overview.rst",
-     "Blender/Python API Overview: a more complete explanation of Python integration"),
+     "API Overview: a more complete explanation of Python integration"),
     ("info_api_reference.rst",
-     "Blender/Python API Reference Usage: examples of how to use the API reference docs"),
+     "API Reference Usage: examples of how to use the API reference docs"),
     ("info_best_practice.rst",
      "Best Practice: Conventions to follow for writing good scripts"),
     ("info_tips_and_tricks.rst",
      "Tips and Tricks: Hints to help you while writing scripts for Blender"),
     ("info_gotcha.rst",
      "Gotcha's: some of the problems you may come up against when writing scripts"),
+    ("change_log.rst", "List of changes since last Blender release"),
 )
 
 # only support for properties atm.
 RNA_BLACKLIST = {
     # XXX messes up PDF!, really a bug but for now just workaround.
-    "UserPreferencesSystem": {"language", }
+    "PreferencesSystem": {"language", }
 }
 
 MODULE_GROUPING = {
@@ -421,7 +399,6 @@ is_release = bpy.app.version_cycle in {"rc", "release"}
 
 # converting bytes to strings, due to T30154
 BLENDER_REVISION = str(bpy.app.build_hash, 'utf_8')
-BLENDER_DATE = str(bpy.app.build_date, 'utf_8')
 
 if is_release:
     # '2.62a'
@@ -429,9 +406,13 @@ if is_release:
 else:
     # '2.62.1'
     BLENDER_VERSION_DOTS = ".".join(blender_version_strings)
+
 if BLENDER_REVISION != "Unknown":
     # '2.62a SHA1' (release) or '2.62.1 SHA1' (non-release)
-    BLENDER_VERSION_DOTS += " " + BLENDER_REVISION          
+    BLENDER_VERSION_HASH = BLENDER_REVISION
+else:
+    # Fallback: Should not be used
+    BLENDER_VERSION_HASH = "Hash Unknown"
 
 if is_release:
     # '2_62a_release'
@@ -449,15 +430,9 @@ BLENDER_ZIP_FILENAME = "%s.zip" % REFERENCE_NAME
 
 # -------------------------------SPHINX-----------------------------------------
 
-if ARGS.sphinx_theme == "blender-org":
-    SPHINX_THEME_DIR = os.path.join(ARGS.output_dir, ARGS.sphinx_theme)
-    SPHINX_THEME_SVN_DIR = os.path.join(SCRIPT_DIR, ARGS.sphinx_theme)
-
 SPHINX_IN = os.path.join(ARGS.output_dir, "sphinx-in")
 SPHINX_IN_TMP = SPHINX_IN + "-tmp"
 SPHINX_OUT = os.path.join(ARGS.output_dir, "sphinx-out")
-if ARGS.sphinx_named_output:
-    SPHINX_OUT += "_%s" % ARGS.sphinx_theme
 
 # html build
 if ARGS.sphinx_build:
@@ -489,7 +464,7 @@ if ARGS.sphinx_build_pdf:
 
 # --------------------------------API DUMP--------------------------------------
 
-# lame, python wont give some access
+# lame, python won't give some access
 ClassMethodDescriptorType = type(dict.__dict__['fromkeys'])
 MethodDescriptorType = type(dict.get)
 GetSetDescriptorType = type(int.real)
@@ -513,6 +488,8 @@ def escape_rst(text):
     """ Escape plain text which may contain characters used by RST.
     """
     return text.translate(escape_rst.trans)
+
+
 escape_rst.trans = str.maketrans({
     "`": "\\`",
     "|": "\\|",
@@ -526,22 +503,7 @@ def is_struct_seq(value):
 
 
 def undocumented_message(module_name, type_name, identifier):
-    return "Undocumented"
-
-    """
-    if str(type_name).startswith('<module'):
-        preloadtitle = '%s.%s' % (module_name, identifier)
-    else:
-        preloadtitle = '%s.%s.%s' % (module_name, type_name, identifier)
-    message = ("Undocumented (`contribute "
-               "<http://wiki.blender.org/index.php/"
-               "Dev:2.5/Py/API/Generating_API_Reference/Contribute"
-               "?action=edit"
-               "&section=new"
-               "&preload=Dev:2.5/Py/API/Generating_API_Reference/Contribute/Howto-message"
-               "&preloadtitle=%s>`_)\n\n" % preloadtitle)
-    return message
-    """
+    return "Undocumented `contribute <https://developer.blender.org/T51061>`"
 
 
 def range_str(val):
@@ -681,12 +643,12 @@ def pyfunc2sphinx(ident, fw, module_name, type_name, identifier, py_func, is_cla
     if type(py_func) == MethodType:
         return
 
-    arg_str = inspect.formatargspec(*inspect.getfullargspec(py_func))
+    arg_str = str(inspect.signature(py_func))
 
     if not is_class:
         func_type = "function"
 
-        # ther rest are class methods
+        # the rest are class methods
     elif arg_str.startswith("(self, ") or arg_str == "(self)":
         arg_str = "()" if (arg_str == "(self)") else ("(" + arg_str[7:])
         func_type = "method"
@@ -820,7 +782,7 @@ def pymodule2sphinx(basepath, module_name, module, title):
     fw(".. module:: %s\n\n" % module_name)
 
     if module.__doc__:
-        # Note, may contain sphinx syntax, dont mangle!
+        # Note, may contain sphinx syntax, don't mangle!
         fw(module.__doc__.strip())
         fw("\n\n")
 
@@ -1015,24 +977,25 @@ def pymodule2sphinx(basepath, module_name, module, title):
 
     file.close()
 
+
 # Changes in Blender will force errors here
 context_type_map = {
+    # context_member: (RNA type, is_collection)
     "active_base": ("ObjectBase", False),
     "active_bone": ("EditBone", False),
     "active_gpencil_frame": ("GreasePencilLayer", True),
     "active_gpencil_layer": ("GPencilLayer", True),
-    "active_gpencil_brush": ("GPencilSculptBrush", False),
-    "active_gpencil_palette": ("GPencilPalette", True),
-    "active_gpencil_palettecolor": ("GPencilPaletteColor", True),
     "active_node": ("Node", False),
     "active_object": ("Object", False),
     "active_operator": ("Operator", False),
     "active_pose_bone": ("PoseBone", False),
+    "active_editable_fcurve": ("FCurve", False),
     "armature": ("Armature", False),
     "bone": ("Bone", False),
     "brush": ("Brush", False),
     "camera": ("Camera", False),
     "cloth": ("ClothModifier", False),
+    "collection": ("LayerCollection", False),
     "collision": ("CollisionModifier", False),
     "curve": ("Curve", False),
     "dynamic_paint": ("DynamicPaintModifier", False),
@@ -1042,42 +1005,47 @@ context_type_map = {
     "edit_movieclip": ("MovieClip", False),
     "edit_object": ("Object", False),
     "edit_text": ("Text", False),
-    "editable_bases": ("ObjectBase", True),
     "editable_bones": ("EditBone", True),
     "editable_gpencil_layers": ("GPencilLayer", True),
     "editable_gpencil_strokes": ("GPencilStroke", True),
     "editable_objects": ("Object", True),
+    "editable_fcurves": ("FCurve", True),
     "fluid": ("FluidSimulationModifier", False),
-    "gpencil_data": ("GreasePencel", False),
+    "gpencil": ("GreasePencil", False),
+    "gpencil_data": ("GreasePencil", False),
     "gpencil_data_owner": ("ID", False),
     "image_paint_object": ("Object", False),
-    "lamp": ("Lamp", False),
     "lattice": ("Lattice", False),
+    "light": ("Light", False),
+    "lightprobe": ("LightProbe", False),
     "line_style": ("FreestyleLineStyle", False),
     "material": ("Material", False),
     "material_slot": ("MaterialSlot", False),
     "mesh": ("Mesh", False),
     "meta_ball": ("MetaBall", False),
     "object": ("Object", False),
+    "objects_in_mode": ("Object", True),
+    "objects_in_mode_unique_data": ("Object", True),
     "particle_edit_object": ("Object", False),
     "particle_settings": ("ParticleSettings", False),
     "particle_system": ("ParticleSystem", False),
     "particle_system_editable": ("ParticleSystem", False),
     "pose_bone": ("PoseBone", False),
+    "pose_object": ("Object", False),
     "scene": ("Scene", False),
     "sculpt_object": ("Object", False),
-    "selectable_bases": ("ObjectBase", True),
     "selectable_objects": ("Object", True),
-    "selected_bases": ("ObjectBase", True),
     "selected_bones": ("EditBone", True),
-    "selected_editable_bases": ("ObjectBase", True),
     "selected_editable_bones": ("EditBone", True),
+    "selected_editable_fcurves": ("FCurve", True),
     "selected_editable_objects": ("Object", True),
     "selected_editable_sequences": ("Sequence", True),
     "selected_nodes": ("Node", True),
     "selected_objects": ("Object", True),
     "selected_pose_bones": ("PoseBone", True),
+    "selected_pose_bones_from_active_object": ("PoseBone", True),
     "selected_sequences": ("Sequence", True),
+    "selected_visible_fcurves": ("FCurve", True),
     "sequences": ("Sequence", True),
     "smoke": ("SmokeModifier", False),
     "soft_body": ("SoftBodyModifier", False),
@@ -1087,11 +1055,12 @@ context_type_map = {
     "texture_user": ("ID", False),
     "texture_user_property": ("Property", False),
     "vertex_paint_object": ("Object", False),
-    "visible_bases": ("ObjectBase", True),
+    "view_layer": ("ViewLayer", False),
     "visible_bones": ("EditBone", True),
     "visible_gpencil_layers": ("GPencilLayer", True),
     "visible_objects": ("Object", True),
     "visible_pose_bones": ("PoseBone", True),
+    "visible_fcurves": ("FCurve", True),
     "weight_paint_object": ("Object", False),
     "world": ("World", False),
 }
@@ -1114,7 +1083,7 @@ def pycontext2sphinx(basepath):
     def write_contex_cls():
 
         fw(title_string("Global Context", "-"))
-        fw("These properties are avilable in any contexts.\n\n")
+        fw("These properties are available in any contexts.\n\n")
 
         # very silly. could make these global and only access once.
         # structs, funcs, ops, props = rna_info.BuildRNAInfo()
@@ -1138,7 +1107,7 @@ def pycontext2sphinx(basepath):
             if prop.description:
                 fw("   %s\n\n" % prop.description)
 
-            # special exception, cant use genric code here for enums
+            # special exception, can't use generic code here for enums
             if prop.type == "enum":
                 enum_text = pyrna_enum2sphinx(prop)
                 if enum_text:
@@ -1260,7 +1229,7 @@ def pyrna2sphinx(basepath):
             if prop.name or prop.description:
                 fw(ident + "   " + ", ".join(val for val in (prop.name, prop.description) if val) + "\n\n")
 
-            # special exception, cant use genric code here for enums
+            # special exception, can't use generic code here for enums
             if enum_text:
                 write_indented_lines(ident + "   ", fw, enum_text)
                 fw("\n")
@@ -1359,7 +1328,7 @@ def pyrna2sphinx(basepath):
             if prop.description:
                 fw("      %s\n\n" % prop.description)
 
-            # special exception, cant use genric code here for enums
+            # special exception, can't use generic code here for enums
             if prop.type == "enum":
                 enum_text = pyrna_enum2sphinx(prop)
                 if enum_text:
@@ -1392,7 +1361,7 @@ def pyrna2sphinx(basepath):
             elif func.return_values:  # multiple return values
                 fw("      :return (%s):\n" % ", ".join(prop.identifier for prop in func.return_values))
                 for prop in func.return_values:
-                    # TODO, pyrna_enum2sphinx for multiple return values... actually dont
+                    # TODO, pyrna_enum2sphinx for multiple return values... actually don't
                     # think we even use this but still!!!
                     type_descr = prop.get_type_description(
                         as_ret=True, class_fmt=":class:`%s`", collection_id=_BPY_PROP_COLLECTION_ID)
@@ -1574,7 +1543,7 @@ def pyrna2sphinx(basepath):
 
     # operators
     def write_ops():
-        API_BASEURL = "https://developer.blender.org/diffusion/B/browse/master/release/scripts "
+        API_BASEURL = "https://developer.blender.org/diffusion/B/browse/master/release/scripts"
         API_BASEURL_ADDON = "https://developer.blender.org/diffusion/BA"
         API_BASEURL_ADDON_CONTRIB = "https://developer.blender.org/diffusion/BAC"
 
@@ -1642,30 +1611,39 @@ def write_sphinx_conf_py(basepath):
     fw("import sys, os\n\n")
     fw("extensions = ['sphinx.ext.intersphinx']\n\n")
     fw("intersphinx_mapping = {'blender_manual': ('https://docs.blender.org/manual/en/dev/', None)}\n\n")
-    fw("project = 'Blender'\n")
-    # fw("master_doc = 'index'\n")
+    fw("project = 'Blender %s Python API'\n" % BLENDER_VERSION_DOTS)
+    fw("master_doc = 'index'\n")
     fw("copyright = u'Blender Foundation'\n")
-    fw("version = '%s - API'\n" % BLENDER_VERSION_DOTS)
-    fw("release = '%s - API'\n" % BLENDER_VERSION_DOTS)
+    fw("version = '%s'\n" % BLENDER_VERSION_HASH)
+    fw("release = '%s'\n" % BLENDER_VERSION_HASH)
 
     # Quiet file not in table-of-contents warnings.
     fw("exclude_patterns = [\n")
     fw("    'include__bmesh.rst',\n")
     fw("]\n\n")
 
-    if ARGS.sphinx_theme != 'default':
-        fw("html_theme = '%s'\n" % ARGS.sphinx_theme)
-
-    if ARGS.sphinx_theme == "blender-org":
-        fw("html_theme_path = ['../']\n")
+    fw("html_title = 'Blender Python API'\n")
+    fw("html_theme = 'sphinx_rtd_theme'\n")
+    fw("html_theme_options = {\n")
+    fw("    'canonical_url': 'https://docs.blender.org/api/current/',\n")
+    # fw("    'analytics_id': '',\n")
+    # fw("    'collapse_navigation': True,\n")
+    fw("    'sticky_navigation': False,\n")
+    fw("    'navigation_depth': 1,\n")
+    # fw("    'includehidden': True,\n")
+    # fw("    'titles_only': False\n")
+    fw("    }\n\n")
 
     # not helpful since the source is generated, adds to upload size.
     fw("html_copy_source = False\n")
     fw("html_show_sphinx = False\n")
+    fw("html_use_opensearch = 'https://docs.blender.org/api/current'\n")
     fw("html_split_index = True\n")
-    fw("html_extra_path = ['__/static/favicon.ico', '__/static/blender_logo.svg']\n")
-    fw("html_favicon = '__/static/favicon.ico'\n")
-    fw("html_logo = '__/static/blender_logo.svg'\n\n")
+    fw("html_static_path = ['static']\n")
+    fw("html_extra_path = ['static/favicon.ico', 'static/blender_logo.svg']\n")
+    fw("html_favicon = 'static/favicon.ico'\n")
+    fw("html_logo = 'static/blender_logo.svg'\n")
+    fw("html_last_updated_fmt = '%m/%d/%Y'\n\n")
 
     # needed for latex, pdf gen
     fw("latex_elements = {\n")
@@ -1685,12 +1663,13 @@ class PatchedPythonDomain(PythonDomain):
             del node['refspecific']
         return super(PatchedPythonDomain, self).resolve_xref(
             env, fromdocname, builder, typ, target, node, contnode)
-
-def setup(sphinx):
-    sphinx.override_domain(PatchedPythonDomain)
 """)
     # end workaround
 
+    fw("def setup(app):\n")
+    fw("    app.add_stylesheet('css/theme_overrides.css')\n")
+    fw("    app.override_domain(PatchedPythonDomain)\n\n")
+
     file.close()
 
 
@@ -1705,34 +1684,32 @@ def write_rst_contents(basepath):
     '''
     Write the rst file of the main page, needed for sphinx (index.html)
     '''
-    filepath = os.path.join(basepath, "contents.rst")
+    filepath = os.path.join(basepath, "index.rst")
     file = open(filepath, "w", encoding="utf-8")
     fw = file.write
 
-    fw(title_string("Blender Documentation Contents", "%", double=True))
+    fw(title_string("Blender %s Python API Documentation" % BLENDER_VERSION_DOTS, "%", double=True))
     fw("\n")
-    fw("Welcome, this document is an API reference for Blender %s, built %s.\n" %
-       (BLENDER_VERSION_DOTS, BLENDER_DATE))
+    fw("Welcome to the Python API documentation for `Blender <https://www.blender.org>`__, ")
+    fw("the free and open source 3D creation suite.\n")
     fw("\n")
 
     # fw("`A PDF version of this document is also available <%s>`_\n" % BLENDER_PDF_FILENAME)
-    fw("This site can be downloaded for offline use `Download the full Documentation (zipped HTML files) <%s>`_\n" %
+    fw("This site can be used offline: `Download the full documentation (zipped HTML files) <%s>`__\n" %
        BLENDER_ZIP_FILENAME)
-
     fw("\n")
 
     if not EXCLUDE_INFO_DOCS:
-        fw(title_string("Blender/Python Documentation", "=", double=True))
-
         fw(".. toctree::\n")
-        fw("   :maxdepth: 1\n\n")
+        fw("   :maxdepth: 1\n")
+        fw("   :caption: Documentation\n\n")
         for info, info_desc in INFO_DOCS:
-            fw("   %s <%s>\n\n" % (info_desc, info))
+            fw("   %s <%s>\n" % (info_desc, info))
         fw("\n")
 
-    fw(title_string("Application Modules", "=", double=True))
     fw(".. toctree::\n")
-    fw("   :maxdepth: 1\n\n")
+    fw("   :maxdepth: 1\n")
+    fw("   :caption: Application Modules\n\n")
 
     app_modules = (
         "bpy.context",  # note: not actually a module
@@ -1752,61 +1729,28 @@ def write_rst_contents(basepath):
 
     for mod in app_modules:
         if mod not in EXCLUDE_MODULES:
-            fw("   %s\n\n" % mod)
+            fw("   %s\n" % mod)
+    fw("\n")
 
-    fw(title_string("Standalone Modules", "=", double=True))
     fw(".. toctree::\n")
-    fw("   :maxdepth: 1\n\n")
+    fw("   :maxdepth: 1\n")
+    fw("   :caption: Standalone Modules\n\n")
 
     standalone_modules = (
         # submodules are added in parent page
-        "mathutils", "freestyle", "bgl", "blf", "gpu",
+        "mathutils", "freestyle", "bgl", "blf", "gpu", "gpu_extras",
         "aud", "bpy_extras", "idprop.types", "bmesh",
     )
 
     for mod in standalone_modules:
         if mod not in EXCLUDE_MODULES:
-            fw("   %s\n\n" % mod)
+            fw("   %s\n" % mod)
+    fw("\n")
 
     # special case, this 'bmesh.ops.rst' is extracted from C source
     if "bmesh.ops" not in EXCLUDE_MODULES:
         execfile(os.path.join(SCRIPT_DIR, "rst_from_bmesh_opdefines.py"))
 
-    # game engine
-    if "bge" not in EXCLUDE_MODULES:
-        fw(title_string("Game Engine Modules", "=", double=True))
-        fw(".. toctree::\n")
-        fw("   :maxdepth: 1\n\n")
-        fw("   bge.types.rst\n\n")
-        fw("   bge.logic.rst\n\n")
-        fw("   bge.render.rst\n\n")
-        fw("   bge.texture.rst\n\n")
-        fw("   bge.events.rst\n\n")
-        fw("   bge.constraints.rst\n\n")
-        fw("   bge.app.rst\n\n")
-
-    # rna generated change log
-    fw(title_string("API Info", "=", double=True))
-    fw(".. toctree::\n")
-    fw("   :maxdepth: 1\n\n")
-    fw("   change_log.rst\n\n")
-
-    fw("\n")
-    fw("\n")
-    fw(".. note:: The Blender Python API has areas which are still in development.\n")
-    fw("   \n")
-    fw("   The following areas are subject to change.\n")
-    fw("      * operator behavior, names and arguments\n")
-    fw("      * mesh creation and editing functions\n")
-    fw("   \n")
-    fw("   These parts of the API are relatively stable and are unlikely to change significantly\n")
-    fw("      * data API, access to attributes of Blender data such as mesh verts, material color,\n")
-    fw("        timeline frames and scene objects\n")
-    fw("      * user interface functions for defining buttons, creation of menus, headers, panels\n")
-    fw("      * render engine integration\n")
-    fw("      * modules: bgl, mathutils & game engine.\n")
-    fw("\n")
-
     file.close()
 
 
@@ -1896,11 +1840,16 @@ def write_rst_importable_modules(basepath):
         "bpy.path": "Path Utilities",
         "bpy.utils": "Utilities",
         "bpy_extras": "Extra Utilities",
+        "gpu_extras": "GPU Utilities",
 
         # C_modules
         "aud": "Audio System",
         "blf": "Font Drawing",
-        "gpu.offscreen": "GPU Off-Screen Buffer",
+        "gpu": "GPU Shader Module",
+        "gpu.types": "GPU Types",
+        "gpu.matrix": "GPU Matrix",
+        "gpu.select": "GPU Select",
+        "gpu.shader": "GPU Shader",
         "bmesh": "BMesh Module",
         "bmesh.types": "BMesh Types",
         "bmesh.utils": "BMesh Utilities",
@@ -1908,6 +1857,8 @@ def write_rst_importable_modules(basepath):
         "bpy.app": "Application Data",
         "bpy.app.handlers": "Application Handlers",
         "bpy.app.translations": "Application Translations",
+        "bpy.app.icons": "Application Icons",
+        "bpy.app.timers": "Application Timers",
         "bpy.props": "Property Definitions",
         "idprop.types": "ID Property Access",
         "mathutils": "Math Types & Utilities",
@@ -1940,36 +1891,18 @@ def copy_handwritten_rsts(basepath):
 
     # TODO put this docs in Blender's code and use import as per modules above
     handwritten_modules = [
-        "bge.logic",
-        "bge.render",
-        "bge.texture",
-        "bge.events",
-        "bge.constraints",
-        "bge.app",
         "bgl",  # "Blender OpenGl wrapper"
-        "gpu",  # "GPU Shader Module"
-
         "bmesh.ops",  # generated by rst_from_bmesh_opdefines.py
 
         # includes...
         "include__bmesh",
     ]
+
     for mod_name in handwritten_modules:
         if mod_name not in EXCLUDE_MODULES:
             # copy2 keeps time/date stamps
             shutil.copy2(os.path.join(RST_DIR, "%s.rst" % mod_name), basepath)
 
-    if "bge.types" not in EXCLUDE_MODULES:
-        shutil.copy2(os.path.join(RST_DIR, "bge.types.rst"), basepath)
-
-        bge_types_dir = os.path.join(RST_DIR, "bge_types")
-
-        for i in os.listdir(bge_types_dir):
-            if i.startswith("."):
-                # Avoid things like .svn dir...
-                continue
-            shutil.copy2(os.path.join(bge_types_dir, i), basepath)
-
     # changelog
     shutil.copy2(os.path.join(RST_DIR, "change_log.rst"), basepath)
 
@@ -1994,6 +1927,12 @@ def copy_handwritten_extra(basepath):
         shutil.copy2(f_src, f_dst)
 
 
+def copy_theme_assets(basepath):
+    shutil.copytree(os.path.join(SCRIPT_DIR, "static"),
+                    os.path.join(basepath, "static"),
+                    copy_function=shutil.copy)
+
+
 def rna2sphinx(basepath):
 
     try:
@@ -2028,6 +1967,9 @@ def rna2sphinx(basepath):
     # copy source files referenced
     copy_handwritten_extra(basepath)
 
+    # copy extra files needed for theme
+    copy_theme_assets(basepath)
+
 
 def align_sphinx_in_to_sphinx_in_tmp(dir_src, dir_dst):
     '''
@@ -2126,15 +2068,6 @@ def main():
                         ignore=shutil.ignore_patterns(*(".svn",)),
                         copy_function=shutil.copy)
 
-        # eventually, copy the theme dir
-        if ARGS.sphinx_theme == "blender-org":
-            if os.path.exists(SPHINX_THEME_DIR):
-                shutil.rmtree(SPHINX_THEME_DIR, True)
-            shutil.copytree(SPHINX_THEME_SVN_DIR,
-                            SPHINX_THEME_DIR,
-                            ignore=shutil.ignore_patterns(*(".svn",)),
-                            copy_function=shutil.copy)
-
     # dump the api in rst files
     if os.path.exists(SPHINX_IN_TMP):
         shutil.rmtree(SPHINX_IN_TMP, True)
@@ -2197,8 +2130,6 @@ def main():
             shutil.copytree(SPHINX_OUT,
                             REFERENCE_PATH,
                             ignore=shutil.ignore_patterns(*ignores))
-            shutil.copy(os.path.join(REFERENCE_PATH, "contents.html"),
-                        os.path.join(REFERENCE_PATH, "index.html"))
 
             # zip REFERENCE_PATH
             basename = os.path.join(ARGS.output_dir, REFERENCE_NAME)
