@@ -35,26 +35,25 @@ class Patch;
 #define DSPLIT_NON_UNIFORM -1
 
 class DiagSplit {
-public:
-	vector<QuadDice::SubPatch> subpatches_quad;
-	vector<QuadDice::EdgeFactors> edgefactors_quad;
+ public:
+  vector<QuadDice::SubPatch> subpatches_quad;
+  vector<QuadDice::EdgeFactors> edgefactors_quad;
 
-	SubdParams params;
+  SubdParams params;
 
-	explicit DiagSplit(const SubdParams& params);
+  explicit DiagSplit(const SubdParams &params);
 
-	float3 to_world(Patch *patch, float2 uv);
-	int T(Patch *patch, float2 Pstart, float2 Pend);
-	void partition_edge(Patch *patch, float2 *P, int *t0, int *t1,
-		float2 Pstart, float2 Pend, int t);
+  float3 to_world(Patch *patch, float2 uv);
+  int T(Patch *patch, float2 Pstart, float2 Pend);
+  void partition_edge(
+      Patch *patch, float2 *P, int *t0, int *t1, float2 Pstart, float2 Pend, int t);
 
-	void dispatch(QuadDice::SubPatch& sub, QuadDice::EdgeFactors& ef);
-	void split(QuadDice::SubPatch& sub, QuadDice::EdgeFactors& ef, int depth=0);
+  void dispatch(QuadDice::SubPatch &sub, QuadDice::EdgeFactors &ef);
+  void split(QuadDice::SubPatch &sub, QuadDice::EdgeFactors &ef, int depth = 0);
 
-	void split_quad(Patch *patch, QuadDice::SubPatch *subpatch=NULL);
+  void split_quad(Patch *patch, QuadDice::SubPatch *subpatch = NULL);
 };
 
 CCL_NAMESPACE_END
 
 #endif /* __SUBD_SPLIT_H__ */
-
