@@ -1,5 +1,5 @@
-/** \file elbeem/intern/solver_util.cpp
- *  \ingroup elbeem
+/** \file
+ * \ingroup elbeem
  */
 /******************************************************************************
  *
@@ -1677,223 +1677,6 @@ LbmFloat& LbmFsgrSolver::debRAC(LbmFloat* s,int l) {
  * GUI&debugging functions
  *****************************************************************************/
 
-
-#if LBM_USE_GUI==1
-#define USE_GLUTILITIES
-#include "../gui/gui_utilities.h"
-
-//! display a single node
-void LbmFsgrSolver::debugDisplayNode(int dispset, CellIdentifierInterface* cell ) {
-	//debugOut(" DD: "<<cell->getAsString() , 10);
-	ntlVec3Gfx org      = this->getCellOrigin( cell );
-	ntlVec3Gfx halfsize = this->getCellSize( cell );
-	int    set      = this->getCellSet( cell );
-	//debugOut(" DD: "<<cell->getAsString()<<" "<< (dispset->type) , 10);
-
-	bool     showcell = true;
-	int      linewidth = 1;
-	ntlColor col(0.5);
-	LbmFloat cscale = 1.0; //dispset->scale;
-
-#define DRAWDISPCUBE(col,scale) \
-	{	glLineWidth( linewidth ); \
-	  glColor3f( (col)[0], (col)[1], (col)[2]); \
-		ntlVec3Gfx s = org-(halfsize * (scale)); \
-		ntlVec3Gfx e = org+(halfsize * (scale)); \
-		drawCubeWire( s,e ); }
-
-	CellFlagType flag = this->getCellFlag(cell, set );
-	// always check types
-	if(flag& CFInvalid  ) { if(!guiShowInvalid  ) return; }
-	if(flag& CFUnused   ) { if(!guiShowInvalid  ) return; }
-	if(flag& CFEmpty    ) { if(!guiShowEmpty    ) return; }
-	if(flag& CFInter    ) { if(!guiShowInterface) return; }
-	if(flag& CFNoDelete ) { if(!guiShowNoDelete ) return; }
-	if(flag& CFBnd      ) { if(!guiShowBnd      ) return; }
-
-	// only dismiss one of these types 
-	if(flag& CFGrFromCoarse)  { if(!guiShowCoarseInner  ) return; } // inner not really interesting
-	else
-	if(flag& CFGrFromFine) { if(!guiShowCoarseBorder ) return; }
-	else
-	if(flag& CFFluid    )    { if(!guiShowFluid    ) return; }
-
-	switch(dispset) {
-		case FLUIDDISPNothing: {
-				showcell = false;
-			} break;
-		case FLUIDDISPCelltypes: {
-				cscale = 0.5;
-
-				if(flag& CFNoDelete) { // debug, mark nodel cells
-					ntlColor ccol(0.7,0.0,0.0);
-					DRAWDISPCUBE(ccol, 0.1);
-				}
-				if(flag& CFPersistMask) { // mark persistent flags
-					ntlColor ccol(0.5);
-					DRAWDISPCUBE(ccol, 0.125);
-				}
-				if(flag& CFNoBndFluid) { // mark persistent flags
-					ntlColor ccol(0,0,1);
-					DRAWDISPCUBE(ccol, 0.075);
-				}
-
-				if(flag& CFInvalid) {
-					cscale = 0.50;
-					col = ntlColor(0.0,0,0.0);
-				}
-				else if(flag& CFBnd) {
-					cscale = 0.59;
-					col = ntlColor(0.4);
-				}
-
-				else if(flag& CFInter) {
-					cscale = 0.55;
-					col = ntlColor(0,1,1);
-
-				} else if(flag& CFGrFromCoarse) {
-					// draw as - with marker
-					ntlColor col2(0.0,1.0,0.3);
-					DRAWDISPCUBE(col2, 0.1);
-					cscale = 0.5;
-					showcell=false; // DEBUG
-				}
-				else if(flag& CFFluid) {
-					cscale = 0.5;
-					if(flag& CFGrToFine) {
-						ntlColor col2(0.5,0.0,0.5);
-						DRAWDISPCUBE(col2, 0.1);
-						col = ntlColor(0,0,1);
-					}
-					if(flag& CFGrFromFine) {
-						ntlColor col2(1.0,1.0,0.0);
-						DRAWDISPCUBE(col2, 0.1);
-						col = ntlColor(0,0,1);
-					} else if(flag& CFGrFromCoarse) {
-						// draw as fluid with marker
-						ntlColor col2(0.0,1.0,0.3);
-						DRAWDISPCUBE(col2, 0.1);
-						col = ntlColor(0,0,1);
-					} else {
-						col = ntlColor(0,0,1);
-					}
-				}
-				else if(flag& CFEmpty) {
-					showcell=false;
-				}
-
-			} break;
-		case FLUIDDISPVelocities: {
-				// dont use cube display
-				LbmVec vel = this->getCellVelocity( cell, set );
-				glBegin(GL_LINES);
-				glColor3f( 0.0,0.0,0.0 );
-				glVertex3f( org[0], org[1], org[2] );
-				org += vec2G(vel * 10.0 * cscale);
-				glColor3f( 1.0,1.0,1.0 );
-				glVertex3f( org[0], org[1], org[2] );
-				glEnd();
-				showcell = false;
-			} break;
-		case FLUIDDISPCellfills: {
-				cscale = 0.5;
-				if(flag& CFFluid) {
-					cscale = 0.75;
-					col = ntlColor(0,0,0.5);
-				}
-				else if(flag& CFInter) {
-					cscale = 0.75 * this->getCellMass(cell,set);
-					col = ntlColor(0,1,1);
-				}
-				else {
-					showcell=false;
-				}
-
-					if( ABS(this->getCellMass(cell,set)) < 10.0 ) {
-						cscale = 0.75 * this->getCellMass(cell,set);
-					} else {
-						showcell = false;
-					}
-					if(cscale>0.0) {
-						col = ntlColor(0,1,1);
-					} else {
-						col = ntlColor(1,1,0);
-					}
-			// TODO
-			} break;
-		case FLUIDDISPDensity: {
-				LbmFloat rho = this->getCellDensity(cell,set);
-				cscale = rho*rho * 0.25;
-				col = ntlColor( MIN(0.5+cscale,1.0) , MIN(0.0+cscale,1.0), MIN(0.0+cscale,1.0) );
-				cscale *= 2.0;
-			} break;
-		case FLUIDDISPGrid: {
-				cscale = 0.59;
-				col = ntlColor(1.0);
-			} break;
-		default: {
-				cscale = 0.5;
-				col = ntlColor(1.0,0.0,0.0);
-			} break;
-	}
-
-	if(!showcell) return;
-	if(cscale==0.0) return; // dont draw zero values
-	DRAWDISPCUBE(col, cscale);
-}
-
-//! debug display function
-//  D has to implement the CellIterator interface
-void LbmFsgrSolver::lbmDebugDisplay(int dispset) {
-	// DEBUG always display testdata
-#if LBM_INCLUDE_TESTSOLVERS==1
-	if(mUseTestdata){ 
-		cpDebugDisplay(dispset); 
-		mpTest->testDebugDisplay(dispset); 
-	}
-#endif // LBM_INCLUDE_TESTSOLVERS==1
-	if(dispset<=FLUIDDISPNothing) return;
-	//if(!dispset->on) return;
-	glDisable( GL_LIGHTING ); // dont light lines
-
-#if LBM_INCLUDE_TESTSOLVERS==1
-	if((!mUseTestdata)|| (mUseTestdata)&&(mpTest->mFarfMode<=0)) {
-#endif // LBM_INCLUDE_TESTSOLVERS==1
-
-	LbmFsgrSolver::CellIdentifier cid = this->getFirstCell();
-	for(; this->noEndCell( cid );
-	      this->advanceCell( cid ) ) {
-		this->debugDisplayNode(dispset, cid );
-	}
-	delete cid;
-
-#if LBM_INCLUDE_TESTSOLVERS==1
-	} // 3d check
-#endif // LBM_INCLUDE_TESTSOLVERS==1
-
-	glEnable( GL_LIGHTING ); // dont light lines
-}
-
-//! debug display function
-//  D has to implement the CellIterator interface
-void LbmFsgrSolver::lbmMarkedCellDisplay() {
-	//fluidDispSettings dispset;
-	// trick - display marked cells as grid displa -> white, big
-	int dispset = FLUIDDISPGrid;
-	glDisable( GL_LIGHTING ); // dont light lines
-	
-	LbmFsgrSolver::CellIdentifier cid = this->markedGetFirstCell();
-	while(cid) {
-		this->debugDisplayNode(dispset, cid );
-		cid = this->markedAdvanceCell();
-	}
-	delete cid;
-
-	glEnable( GL_LIGHTING ); // dont light lines
-}
-
-#endif // LBM_USE_GUI==1
-
 //! display a single node
 void LbmFsgrSolver::debugPrintNodeInfo(CellIdentifierInterface* cell, int forceSet) {
 		//string printInfo,
