@@ -1,10 +1,8 @@
 /*
- * ***** BEGIN GPL LICENSE BLOCK *****
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version. 
+ * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,10 +15,7 @@
  *
  * The Original Code is Copyright (C) 2012 Blender Foundation.
  * All rights reserved.
- * 
- * Contributor(s): Alexandr Kuznetsov, Andrea Weikert
  *
- * ***** END GPL LICENSE BLOCK *****
  */
 
 #ifndef __UTFCONV_H__
@@ -30,8 +25,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#ifdef __cplusplus 
-extern  "C" {
+#ifdef __cplusplus
+extern "C" {
 #endif
 
 /**
@@ -53,8 +48,9 @@ size_t count_utf_16_from_8(const char *string8);
  */
 #define UTF_ERROR_NULL_IN 1 << 0 /* Error occures when requered parameter is missing*/
 #define UTF_ERROR_ILLCHAR 1 << 1 /* Error if character is in illigal UTF rage*/
-#define UTF_ERROR_SMALL   1 << 2 /* Passed size is to small. It gives legal string with character missing at the end*/
-#define UTF_ERROR_ILLSEQ  1 << 3 /* Error if sequence is broken and doesn't finish*/
+#define UTF_ERROR_SMALL \
+  1 << 2 /* Passed size is to small. It gives legal string with character missing at the end*/
+#define UTF_ERROR_ILLSEQ 1 << 3 /* Error if sequence is broken and doesn't finish*/
 
 /**
  * Converts utf-16 string to allocated utf-8 string
@@ -74,7 +70,6 @@ int conv_utf_16_to_8(const wchar_t *in16, char *out8, size_t size8);
  */
 int conv_utf_8_to_16(const char *in8, wchar_t *out16, size_t size16);
 
-
 /**
  * Allocates and converts the utf-8 string from utf-16
  * @param in16 utf-16 string to convert
@@ -86,20 +81,25 @@ char *alloc_utf_8_from_16(const wchar_t *in16, size_t add);
 /**
  * Allocates and converts the utf-16 string from utf-8
  * @param in8 utf-8 string to convert
- * @param add any additional size which will be allocated for new utf-16 string in wchar_t (two bytes)
+ * @param add any additional size which will be allocated for new utf-16 string
+ * in wchar_t (two bytes)
  * @return New allocated and converted utf-16 string or NULL if in8 is 0.
  */
 wchar_t *alloc_utf16_from_8(const char *in8, size_t add);
 
-/* Easy allocation and conversion of new utf-16 string. New string has _16 suffix. Must be deallocated with UTF16_UN_ENCODE in right order*/
-#define UTF16_ENCODE(in8str) if (1) { \
-		wchar_t *in8str ## _16 = alloc_utf16_from_8((const char *)in8str, 0)
+/* Easy allocation and conversion of new utf-16 string. New string has _16 suffix.
+ * Must be deallocated with UTF16_UN_ENCODE in right order. */
+#define UTF16_ENCODE(in8str) \
+  if (1) { \
+    wchar_t *in8str##_16 = alloc_utf16_from_8((const char *)in8str, 0)
 
 #define UTF16_UN_ENCODE(in8str) \
-	free(in8str ## _16); } (void)0
+  free(in8str##_16); \
+  } \
+  (void)0
 
-#ifdef __cplusplus 
+#ifdef __cplusplus
 }
 #endif
 
-#endif  /* __UTFCONV_H__ */
+#endif /* __UTFCONV_H__ */
