@@ -2,9 +2,10 @@
 
 # This script updates icons from the SVG file
 import os
+import subprocess
 import sys
 
-BASEDIR = os.path.abspath(os.path.dirname(__file__)) + os.sep
+BASEDIR = os.path.abspath(os.path.dirname(__file__))
 
 inkscape_path = 'inkscape'
 
@@ -13,5 +14,10 @@ if sys.platform == 'darwin':
     if os.path.exists(inkscape_app_path):
         inkscape_path = inkscape_app_path
 
-cmd = inkscape_path + ' "%sprvicons.svg" --without-gui --export-png="%sprvicons.png"' % (BASEDIR, BASEDIR)
-os.system(cmd)
+cmd = (
+    inkscape_path,
+    os.path.join(BASEDIR, "prvicons.svg"),
+    "--without-gui",
+    "--export-png=" + os.path.join(BASEDIR, "prvicons.png"),
+)
+subprocess.check_call(cmd)
