@@ -10,8 +10,14 @@ from math import (
 from bpy.props import (
         FloatProperty,
         IntProperty,
+        BoolProperty,
+        StringProperty,
+        FloatVectorProperty
+        )
+from mathutils import (
+        Vector,
+        Matrix,
         )
-
 
 # Create a new mesh (object) from verts/edges/faces.
 # verts/edges/faces ... List of vertices/edges/faces for the
@@ -261,7 +267,7 @@ def add_gear(teethNum, radius, Ad, De, base, p_angle,
     if rack:
         teethNum = 1
 
-    print(radius, width, conangle)
+    #print(radius, width, conangle)
     scale = (radius - 2 * width * tan(conangle)) / radius
 
     verts = []
@@ -461,7 +467,7 @@ def add_spokes(teethNum, radius, De, base, width=1, conangle=0, rack=0,
 # crown ... Inward pointing extend of crown teeth
 #
 # @todo: Fix teethNum. Some numbers are not possible yet
-# @todo: Create start & end geoemtry (closing faces)
+# @todo: Create start & end geometry (closing faces)
 
 def add_worm(teethNum, rowNum, radius, Ad, De, p_angle,
              width=1, skew=radians(11.25), crown=0.0):
@@ -547,76 +553,131 @@ def add_worm(teethNum, rowNum, radius, Ad, De, p_angle,
 
     return verts, faces, vgroup_top, vgroup_valley
 
+#### Delete object
+def ObjectDelete(self, context, delete):
+
+    bpy.context.view_layer.update()
+    bpy.ops.object.mode_set(mode = 'OBJECT')
+    bpy.ops.object.delete()
+    bpy.context.view_layer.update()
+
+    return
+    
+##------------------------------------------------------------
+# calculates the matrix for the new object
+# depending on user pref
+def align_matrix(context, location):
+
+    loc = Matrix.Translation(location)
+    obj_align = context.preferences.edit.object_align
+    if (context.space_data.type == 'VIEW_3D'
+        and obj_align == 'VIEW'):
+        rot = context.space_data.region_3d.view_matrix.to_3x3().inverted().to_4x4()
+    else:
+        rot = Matrix()
+    align_matrix = loc @ rot
+
+    return align_matrix
 
 class AddGear(Operator):
     bl_idname = "mesh.primitive_gear"
     bl_label = "Add Gear"
     bl_description = "Construct a gear mesh"
     bl_options = {'REGISTER', 'UNDO', 'PRESET'}
+    
+    # align_matrix for the invoke
+    align_matrix : Matrix()
 
-    number_of_teeth = IntProperty(name="Number of Teeth",
+    Gear : BoolProperty(name = "Gear",
+                default = True,
+                description = "Gear")
+
+    #### change properties
+    name : StringProperty(name = "Name",
+                    description = "Name")
+
+    change : BoolProperty(name = "Change",
+                default = False,
+                description = "change Gear")
+
+    delete : StringProperty(name = "Delete",
+                    description = "Delete Gear")
+
+    startlocation : FloatVectorProperty(name = "",
+                description = "Start location",
+                default = (0.0, 0.0, 0.0),
+                subtype = 'XYZ')
+
+    rotation_euler : FloatVectorProperty(
+            name="",
+            description="Rotation",
+            default=(0.0, 0.0, 0.0),
+            subtype='EULER'
+            )
+
+    number_of_teeth: IntProperty(name="Number of Teeth",
             description="Number of teeth on the gear",
             min=2,
             max=265,
             default=12
             )
-    radius = FloatProperty(name="Radius",
+    radius: FloatProperty(name="Radius",
             description="Radius of the gear, negative for crown gear",
             min=-100.0,
             max=100.0,
             unit='LENGTH',
             default=1.0
             )
-    addendum = FloatProperty(name="Addendum",
+    addendum: FloatProperty(name="Addendum",
             description="Addendum, extent of tooth above radius",
             min=0.01,
             max=100.0,
             unit='LENGTH',
             default=0.1
             )
-    dedendum = FloatProperty(name="Dedendum",
+    dedendum: FloatProperty(name="Dedendum",
             description="Dedendum, extent of tooth below radius",
             min=0.0,
             max=100.0,
             unit='LENGTH',
             default=0.1
             )
-    angle = FloatProperty(name="Pressure Angle",
+    angle: FloatProperty(name="Pressure Angle",
             description="Pressure angle, skewness of tooth tip",
             min=0.0,
             max=radians(45.0),
             unit='ROTATION',
             default=radians(20.0)
             )
-    base = FloatProperty(name="Base",
+    base: FloatProperty(name="Base",
             description="Base, extent of gear below radius",
             min=0.0,
             max=100.0,
             unit='LENGTH',
             default=0.2
             )
-    width = FloatProperty(name="Width",
+    width: FloatProperty(name="Width",
             description="Width, thickness of gear",
             min=0.05,
             max=100.0,
             unit='LENGTH',
             default=0.2
             )
-    skew = FloatProperty(name="Skewness",
+    skew: FloatProperty(name="Skewness",
             description="Skew of teeth",
             min=radians(-90.0),
             max=radians(90.0),
             unit='ROTATION',
             default=radians(0.0)
             )
-    conangle = FloatProperty(name="Conical angle",
+    conangle: FloatProperty(name="Conical angle",
             description="Conical angle of gear",
             min=0.0,
             max=radians(90.0),
             unit='ROTATION',
             default=radians(0.0)
             )
-    crown = FloatProperty(name="Crown",
+    crown: FloatProperty(name="Crown",
             description="Inward pointing extend of crown teeth",
             min=0.0,
             max=100.0,
@@ -645,7 +706,18 @@ class AddGear(Operator):
         box.prop(self, 'conangle')
         box.prop(self, 'crown')
 
+        box = layout.box()
+        box.label(text="Location:")
+        box.prop(self, "startlocation")
+        box = layout.box()
+        box.label(text="Rotation:")
+        box.prop(self, "rotation_euler")
+
     def execute(self, context):
+
+        if self.change:
+            ObjectDelete(self, context, self.delete)
+
         verts, faces, verts_tip, verts_valley = add_gear(
             self.number_of_teeth,
             self.radius,
@@ -660,20 +732,50 @@ class AddGear(Operator):
             )
 
         # Actually create the mesh object from this geometry data.
-        base = create_mesh_object(context, verts, [], faces, "Gear")
-        obj = base.object
+        obj = create_mesh_object(context, verts, [], faces, "Gear")
+        
+        self.align_matrix = align_matrix(context, self.startlocation)
+        
+        obj.matrix_world = self.align_matrix  # apply matrix
+        obj.rotation_euler = self.rotation_euler
 
         # XXX, supporting adding in editmode is move involved
         if obj.mode != 'EDIT':
             # Create vertex groups from stored vertices.
-            tipGroup = obj.vertex_groups.new('Tips')
+            tipGroup = obj.vertex_groups.new(name='Tips')
             tipGroup.add(verts_tip, 1.0, 'ADD')
 
-            valleyGroup = obj.vertex_groups.new('Valleys')
+            valleyGroup = obj.vertex_groups.new(name='Valleys')
             valleyGroup.add(verts_valley, 1.0, 'ADD')
 
+        obj["Gear"] = True
+        obj["change"] = False
+        obj["number_of_teeth"] = self.number_of_teeth
+        obj["radius"] = self.radius
+        obj["addendum"] = self.addendum
+        obj["dedendum"] = self.dedendum
+        obj["base"] = self.base
+        obj["angle"] = self.angle
+        obj["width"] = self.width
+        obj["skew"] = self.skew
+        obj["conangle"] = self.conangle
+        obj["crown"] = self.crown
+
         return {'FINISHED'}
 
+    ##### INVOKE #####
+    def invoke(self, context, event):
+        bpy.context.view_layer.update()
+        if self.change:
+            bpy.context.scene.cursor.location = self.startlocation
+        else:
+            self.startlocation = bpy.context.scene.cursor.location
+        
+        self.align_matrix = align_matrix(context, self.startlocation)
+
+        self.execute(context)
+
+        return {'FINISHED'}
 
 class AddWormGear(Operator):
     bl_idname = "mesh.primitive_worm_gear"
@@ -681,21 +783,51 @@ class AddWormGear(Operator):
     bl_description = "Construct a worm gear mesh"
     bl_options = {'REGISTER', 'UNDO', 'PRESET'}
 
-    number_of_teeth = IntProperty(
+    # align_matrix for the invoke
+    align_matrix : Matrix()
+
+    WormGear : BoolProperty(name = "WormGear",
+                default = True,
+                description = "WormGear")
+
+    #### change properties
+    name : StringProperty(name = "Name",
+                    description = "Name")
+
+    change : BoolProperty(name = "Change",
+                default = False,
+                description = "change WormGear")
+
+    delete : StringProperty(name = "Delete",
+                    description = "Delete WormGear")
+
+    startlocation : FloatVectorProperty(name = "",
+                description = "Start location",
+                default = (0.0, 0.0, 0.0),
+                subtype = 'XYZ')
+
+    rotation_euler : FloatVectorProperty(
+            name="",
+            description="Rotation",
+            default=(0.0, 0.0, 0.0),
+            subtype='EULER'
+            )
+
+    number_of_teeth: IntProperty(
             name="Number of Teeth",
             description="Number of teeth on the gear",
             min=2,
             max=265,
             default=12
             )
-    number_of_rows = IntProperty(
+    number_of_rows: IntProperty(
             name="Number of Rows",
             description="Number of rows on the worm gear",
             min=2,
             max=265,
             default=32
             )
-    radius = FloatProperty(
+    radius: FloatProperty(
             name="Radius",
             description="Radius of the gear, negative for crown gear",
             min=-100.0,
@@ -703,7 +835,7 @@ class AddWormGear(Operator):
             unit='LENGTH',
             default=1.0
             )
-    addendum = FloatProperty(
+    addendum: FloatProperty(
             name="Addendum",
             description="Addendum, extent of tooth above radius",
             min=0.01,
@@ -711,7 +843,7 @@ class AddWormGear(Operator):
             unit='LENGTH',
             default=0.1
             )
-    dedendum = FloatProperty(
+    dedendum: FloatProperty(
             name="Dedendum",
             description="Dedendum, extent of tooth below radius",
             min=0.0,
@@ -719,7 +851,7 @@ class AddWormGear(Operator):
             unit='LENGTH',
             default=0.1
             )
-    angle = FloatProperty(
+    angle: FloatProperty(
             name="Pressure Angle",
             description="Pressure angle, skewness of tooth tip",
             min=0.0,
@@ -727,7 +859,7 @@ class AddWormGear(Operator):
             default=radians(20.0),
             unit='ROTATION'
             )
-    row_height = FloatProperty(
+    row_height: FloatProperty(
             name="Row Height",
             description="Height of each Row",
             min=0.05,
@@ -735,7 +867,7 @@ class AddWormGear(Operator):
             unit='LENGTH',
             default=0.2
             )
-    skew = FloatProperty(
+    skew: FloatProperty(
             name="Skewness per Row",
             description="Skew of each row",
             min=radians(-90.0),
@@ -743,7 +875,7 @@ class AddWormGear(Operator):
             default=radians(11.25),
             unit='ROTATION'
             )
-    crown = FloatProperty(
+    crown: FloatProperty(
             name="Crown",
             description="Inward pointing extend of crown teeth",
             min=0.0,
@@ -769,8 +901,18 @@ class AddWormGear(Operator):
         box.prop(self, "skew")
         box.prop(self, "crown")
 
+        box = layout.box()
+        box.label(text="Location:")
+        box.prop(self, "startlocation")
+        box = layout.box()
+        box.label(text="Rotation:")
+        box.prop(self, "rotation_euler")
+
     def execute(self, context):
 
+        if self.change:
+            ObjectDelete(self, context, self.delete)
+        
         verts, faces, verts_tip, verts_valley = add_worm(
             self.number_of_teeth,
             self.number_of_rows,
@@ -784,16 +926,48 @@ class AddWormGear(Operator):
             )
 
         # Actually create the mesh object from this geometry data.
-        base = create_mesh_object(context, verts, [], faces, "Worm Gear")
-        obj = base.object
+        obj = create_mesh_object(context, verts, [], faces, "Worm Gear")
+        
+        self.align_matrix = align_matrix(context, self.startlocation)
+        
+        obj.matrix_world = self.align_matrix  # apply matrix
+        obj.rotation_euler = self.rotation_euler
 
         # XXX, supporting adding in editmode is move involved
         if obj.mode != 'EDIT':
             # Create vertex groups from stored vertices.
-            tipGroup = obj.vertex_groups.new('Tips')
+            tipGroup = obj.vertex_groups.new(name = 'Tips')
             tipGroup.add(verts_tip, 1.0, 'ADD')
 
-            valleyGroup = obj.vertex_groups.new('Valleys')
+            valleyGroup = obj.vertex_groups.new(name = 'Valleys')
             valleyGroup.add(verts_valley, 1.0, 'ADD')
+        
+        self.align_matrix = align_matrix(context, self.startlocation)
+        
+        obj["WormGear"] = True
+        obj["change"] = False
+        obj["number_of_teeth"] = self.number_of_teeth
+        obj["number_of_rows"] = self.number_of_rows
+        obj["radius"] = self.radius
+        obj["addendum"] = self.addendum
+        obj["dedendum"] = self.dedendum
+        obj["angle"] = self.angle
+        obj["row_height"] = self.row_height
+        obj["skew"] = self.skew
+        obj["crown"] = self.crown
+
+        return {'FINISHED'}
+
+    ##### INVOKE #####
+    def invoke(self, context, event):
+        bpy.context.view_layer.update()
+        if self.change:
+            bpy.context.scene.cursor.location = self.startlocation
+        else:
+            self.startlocation = bpy.context.scene.cursor.location
+        
+        self.align_matrix = align_matrix(context, self.startlocation)
+
+        self.execute(context)
 
         return {'FINISHED'}
