@@ -18,11 +18,15 @@
 
 # <pep8 compliant>
 
-UI_SLIDERS = '''
-import bpy
-from mathutils import Matrix, Vector
-from math import acos, pi, radians
+UI_IMPORTS = [
+    'import bpy',
+    'from bpy.props import StringProperty',
+    'import math',
+    'from math import pi',
+    'from mathutils import Euler, Matrix, Quaternion, Vector',
+]
 
+UI_BASE_UTILITIES = '''
 rig_id = "%s"
 
 
@@ -54,7 +58,7 @@ def rotation_difference(mat1, mat2):
     """
     q1 = mat1.to_quaternion()
     q2 = mat2.to_quaternion()
-    angle = acos(min(1,max(-1,q1.dot(q2)))) * 2
+    angle = math.acos(min(1,max(-1,q1.dot(q2)))) * 2
     if angle > pi:
         angle = -angle + (2*pi)
     return angle
@@ -67,7 +71,7 @@ def tail_distance(angle,bone_ik,bone_fk):
     if rot_mod != 'AXIS_ANGLE':
         bone_ik.rotation_mode = 'AXIS_ANGLE'
     bone_ik.rotation_axis_angle[0] = angle
-    bpy.context.scene.update()
+    bpy.context.view_layer.update()
 
     dv = (bone_fk.tail - bone_ik.tail).length
 
@@ -135,11 +139,11 @@ def get_pose_matrix_in_other_space(mat, pose_bone):
         par_rest = Matrix()
 
     # Get matrix in bone's current transform space
-    smat = rest_inv * (par_rest * (par_inv * mat))
+    smat = rest_inv @ (par_rest @ (par_inv @ mat))
 
     # Compensate for non-local location
     #if not pose_bone.bone.use_local_location:
-    #    loc = smat.to_translation() * (par_rest.inverted() * rest).to_quaternion()
+    #    loc = smat.to_translation() @ (par_rest.inverted() @ rest).to_quaternion()
     #    smat.translation = loc
 
     return smat
@@ -166,8 +170,8 @@ def set_pose_translation(pose_bone, mat):
         else:
             par_rest = Matrix()
 
-        q = (par_rest.inverted() * rest).to_quaternion()
-        pose_bone.location = q * loc
+        q = (par_rest.inverted() @ rest).to_quaternion()
+        pose_bone.location = q @ loc
 
 
 def set_pose_rotation(pose_bone, mat):
@@ -283,11 +287,11 @@ def match_pole_target(ik_first, ik_last, pole, match_bone, length):
     angle = rotation_difference(ik_first.matrix, match_bone.matrix)
 
     # Try compensating for the rotation difference in both directions
-    pv1 = Matrix.Rotation(angle, 4, ikv) * pv
+    pv1 = Matrix.Rotation(angle, 4, ikv) @ pv
     set_pole(pv1)
     ang1 = rotation_difference(ik_first.matrix, match_bone.matrix)
 
-    pv2 = Matrix.Rotation(-angle, 4, ikv) * pv
+    pv2 = Matrix.Rotation(-angle, 4, ikv) @ pv
     set_pole(pv2)
     ang2 = rotation_difference(ik_first.matrix, match_bone.matrix)
 
@@ -295,6 +299,22 @@ def match_pole_target(ik_first, ik_last, pole, match_bone, length):
     if ang1 < ang2:
         set_pole(pv1)
 
+##########
+## Misc ##
+##########
+
+def parse_bone_names(names_string):
+    if names_string[0] == '[' and names_string[-1] == ']':
+        return eval(names_string)
+    else:
+        return names_string
+
+'''
+
+UTILITIES_FUNC_ARM_FKIK = ['''
+######################
+## IK Arm functions ##
+######################
 
 def fk2ik_arm(obj, fk, ik):
     """ Matches the fk bones in an arm rig to the ik bones.
@@ -390,6 +410,12 @@ def ik2fk_arm(obj, fk, ik):
         match_pose_scale(uarmi, uarm)
         # Rotation Correction
         correct_rotation(uarmi, uarm)
+''']
+
+UTILITIES_FUNC_LEG_FKIK = ['''
+######################
+## IK Leg functions ##
+######################
 
 def fk2ik_leg(obj, fk, ik):
     """ Matches the fk bones in a leg rig to the ik bones.
@@ -424,8 +450,8 @@ def fk2ik_leg(obj, fk, ik):
         match_pose_scale(shin, shini)
 
         # Foot position
-        mat = mfoot.bone.matrix_local.inverted() * foot.bone.matrix_local
-        footmat = get_pose_matrix_in_other_space(mfooti.matrix, foot) * mat
+        mat = mfoot.bone.matrix_local.inverted() @ foot.bone.matrix_local
+        footmat = get_pose_matrix_in_other_space(mfooti.matrix, foot) @ mat
         set_pose_rotation(foot, footmat)
         set_pose_scale(foot, footmat)
         bpy.ops.object.mode_set(mode='OBJECT')
@@ -442,8 +468,8 @@ def fk2ik_leg(obj, fk, ik):
         match_pose_scale(shin, shini)
 
         # Foot position
-        mat = mfoot.bone.matrix_local.inverted() * foot.bone.matrix_local
-        footmat = get_pose_matrix_in_other_space(mfooti.matrix, foot) * mat
+        mat = mfoot.bone.matrix_local.inverted() @ foot.bone.matrix_local
+        footmat = get_pose_matrix_in_other_space(mfooti.matrix, foot) @ mat
         set_pose_rotation(foot, footmat)
         set_pose_scale(foot, footmat)
         bpy.ops.object.mode_set(mode='OBJECT')
@@ -482,8 +508,8 @@ def ik2fk_leg(obj, fk, ik):
         set_pose_rotation(footroll, Matrix())
 
         # Foot position
-        mat = mfooti.bone.matrix_local.inverted() * footi.bone.matrix_local
-        footmat = get_pose_matrix_in_other_space(foot.matrix, footi) * mat
+        mat = mfooti.bone.matrix_local.inverted() @ footi.bone.matrix_local
+        footmat = get_pose_matrix_in_other_space(foot.matrix, footi) @ mat
         set_pose_translation(footi, footmat)
         set_pose_rotation(footi, footmat)
         set_pose_scale(footi, footmat)
@@ -508,8 +534,8 @@ def ik2fk_leg(obj, fk, ik):
         set_pose_rotation(footroll, Matrix())
 
         # Foot position
-        mat = mfooti.bone.matrix_local.inverted() * footi.bone.matrix_local
-        footmat = get_pose_matrix_in_other_space(mfoot.matrix, footi) * mat
+        mat = mfooti.bone.matrix_local.inverted() @ footi.bone.matrix_local
+        footmat = get_pose_matrix_in_other_space(mfoot.matrix, footi) @ mat
         set_pose_translation(footi, footmat)
         set_pose_rotation(footi, footmat)
         set_pose_scale(footi, footmat)
@@ -518,18 +544,13 @@ def ik2fk_leg(obj, fk, ik):
 
         # Pole target position
         match_pole_target(thighi, shini, pole, thigh, (thighi.length + shini.length))
+''']
 
-
+UTILITIES_FUNC_POLE = ['''
 ################################
 ## IK Rotation-Pole functions ##
 ################################
 
-def parse_bone_names(names_string):
-    if names_string[0] == '[' and names_string[-1] == ']':
-        return eval(names_string)
-    else:
-        return names_string
-
 def rotPoleToggle(rig, limb_type, controls, ik_ctrl, fk_ctrl, parent, pole):
 
     rig_id = rig.data['rig_id']
@@ -588,37 +609,36 @@ def rotPoleToggle(rig, limb_type, controls, ik_ctrl, fk_ctrl, parent, pole):
             func2(**kwargs2)
 
             bpy.ops.pose.select_all(action='DESELECT')
+''']
 
-##############################
-## IK/FK snapping operators ##
-##############################
+REGISTER_OP_ARM_FKIK = ['Rigify_Arm_FK2IK', 'Rigify_Arm_IK2FK']
+
+UTILITIES_OP_ARM_FKIK = ['''
+##################################
+## IK/FK Arm snapping operators ##
+##################################
 
 class Rigify_Arm_FK2IK(bpy.types.Operator):
     """ Snaps an FK arm to an IK arm.
     """
     bl_idname = "pose.rigify_arm_fk2ik_" + rig_id
     bl_label = "Rigify Snap FK arm to IK"
-    bl_options = {'UNDO'}
+    bl_options = {'UNDO', 'INTERNAL'}
 
-    uarm_fk = bpy.props.StringProperty(name="Upper Arm FK Name")
-    farm_fk = bpy.props.StringProperty(name="Forerm FK Name")
-    hand_fk = bpy.props.StringProperty(name="Hand FK Name")
+    uarm_fk: StringProperty(name="Upper Arm FK Name")
+    farm_fk: StringProperty(name="Forerm FK Name")
+    hand_fk: StringProperty(name="Hand FK Name")
 
-    uarm_ik = bpy.props.StringProperty(name="Upper Arm IK Name")
-    farm_ik = bpy.props.StringProperty(name="Forearm IK Name")
-    hand_ik = bpy.props.StringProperty(name="Hand IK Name")
+    uarm_ik: StringProperty(name="Upper Arm IK Name")
+    farm_ik: StringProperty(name="Forearm IK Name")
+    hand_ik: StringProperty(name="Hand IK Name")
 
     @classmethod
     def poll(cls, context):
         return (context.active_object != None and context.mode == 'POSE')
 
     def execute(self, context):
-        use_global_undo = context.user_preferences.edit.use_global_undo
-        context.user_preferences.edit.use_global_undo = False
-        try:
-            fk2ik_arm(context.active_object, fk=[self.uarm_fk, self.farm_fk, self.hand_fk], ik=[self.uarm_ik, self.farm_ik, self.hand_ik])
-        finally:
-            context.user_preferences.edit.use_global_undo = use_global_undo
+        fk2ik_arm(context.active_object, fk=[self.uarm_fk, self.farm_fk, self.hand_fk], ik=[self.uarm_ik, self.farm_ik, self.hand_ik])
         return {'FINISHED'}
 
 
@@ -627,61 +647,58 @@ class Rigify_Arm_IK2FK(bpy.types.Operator):
     """
     bl_idname = "pose.rigify_arm_ik2fk_" + rig_id
     bl_label = "Rigify Snap IK arm to FK"
-    bl_options = {'UNDO'}
+    bl_options = {'UNDO', 'INTERNAL'}
 
-    uarm_fk = bpy.props.StringProperty(name="Upper Arm FK Name")
-    farm_fk = bpy.props.StringProperty(name="Forerm FK Name")
-    hand_fk = bpy.props.StringProperty(name="Hand FK Name")
+    uarm_fk: StringProperty(name="Upper Arm FK Name")
+    farm_fk: StringProperty(name="Forerm FK Name")
+    hand_fk: StringProperty(name="Hand FK Name")
 
-    uarm_ik = bpy.props.StringProperty(name="Upper Arm IK Name")
-    farm_ik = bpy.props.StringProperty(name="Forearm IK Name")
-    hand_ik = bpy.props.StringProperty(name="Hand IK Name")
-    pole    = bpy.props.StringProperty(name="Pole IK Name")
+    uarm_ik: StringProperty(name="Upper Arm IK Name")
+    farm_ik: StringProperty(name="Forearm IK Name")
+    hand_ik: StringProperty(name="Hand IK Name")
+    pole   : StringProperty(name="Pole IK Name")
 
-    main_parent = bpy.props.StringProperty(name="Main Parent", default="")
+    main_parent: StringProperty(name="Main Parent", default="")
 
     @classmethod
     def poll(cls, context):
         return (context.active_object != None and context.mode == 'POSE')
 
     def execute(self, context):
-        use_global_undo = context.user_preferences.edit.use_global_undo
-        context.user_preferences.edit.use_global_undo = False
-        try:
-            ik2fk_arm(context.active_object, fk=[self.uarm_fk, self.farm_fk, self.hand_fk], ik=[self.uarm_ik, self.farm_ik, self.hand_ik, self.pole, self.main_parent])
-        finally:
-            context.user_preferences.edit.use_global_undo = use_global_undo
+        ik2fk_arm(context.active_object, fk=[self.uarm_fk, self.farm_fk, self.hand_fk], ik=[self.uarm_ik, self.farm_ik, self.hand_ik, self.pole, self.main_parent])
         return {'FINISHED'}
+''']
 
+REGISTER_OP_LEG_FKIK = ['Rigify_Leg_FK2IK', 'Rigify_Leg_IK2FK']
+
+UTILITIES_OP_LEG_FKIK = ['''
+##################################
+## IK/FK Leg snapping operators ##
+##################################
 
 class Rigify_Leg_FK2IK(bpy.types.Operator):
     """ Snaps an FK leg to an IK leg.
     """
     bl_idname = "pose.rigify_leg_fk2ik_" + rig_id
     bl_label = "Rigify Snap FK leg to IK"
-    bl_options = {'UNDO'}
+    bl_options = {'UNDO', 'INTERNAL'}
 
-    thigh_fk = bpy.props.StringProperty(name="Thigh FK Name")
-    shin_fk  = bpy.props.StringProperty(name="Shin FK Name")
-    foot_fk  = bpy.props.StringProperty(name="Foot FK Name")
-    mfoot_fk = bpy.props.StringProperty(name="MFoot FK Name")
+    thigh_fk: StringProperty(name="Thigh FK Name")
+    shin_fk:  StringProperty(name="Shin FK Name")
+    foot_fk:  StringProperty(name="Foot FK Name")
+    mfoot_fk: StringProperty(name="MFoot FK Name")
 
-    thigh_ik = bpy.props.StringProperty(name="Thigh IK Name")
-    shin_ik  = bpy.props.StringProperty(name="Shin IK Name")
-    foot_ik  = bpy.props.StringProperty(name="Foot IK Name")
-    mfoot_ik = bpy.props.StringProperty(name="MFoot IK Name")
+    thigh_ik: StringProperty(name="Thigh IK Name")
+    shin_ik:  StringProperty(name="Shin IK Name")
+    foot_ik:  StringProperty(name="Foot IK Name")
+    mfoot_ik: StringProperty(name="MFoot IK Name")
 
     @classmethod
     def poll(cls, context):
         return (context.active_object != None and context.mode == 'POSE')
 
     def execute(self, context):
-        use_global_undo = context.user_preferences.edit.use_global_undo
-        context.user_preferences.edit.use_global_undo = False
-        try:
-            fk2ik_leg(context.active_object, fk=[self.thigh_fk, self.shin_fk, self.foot_fk, self.mfoot_fk], ik=[self.thigh_ik, self.shin_ik, self.foot_ik, self.mfoot_ik])
-        finally:
-            context.user_preferences.edit.use_global_undo = use_global_undo
+        fk2ik_leg(context.active_object, fk=[self.thigh_fk, self.shin_fk, self.foot_fk, self.mfoot_fk], ik=[self.thigh_ik, self.shin_ik, self.foot_ik, self.mfoot_ik])
         return {'FINISHED'}
 
 
@@ -690,34 +707,33 @@ class Rigify_Leg_IK2FK(bpy.types.Operator):
     """
     bl_idname = "pose.rigify_leg_ik2fk_" + rig_id
     bl_label = "Rigify Snap IK leg to FK"
-    bl_options = {'UNDO'}
+    bl_options = {'UNDO', 'INTERNAL'}
 
-    thigh_fk = bpy.props.StringProperty(name="Thigh FK Name")
-    shin_fk  = bpy.props.StringProperty(name="Shin FK Name")
-    mfoot_fk = bpy.props.StringProperty(name="MFoot FK Name")
-    foot_fk = bpy.props.StringProperty(name="Foot FK Name", default="")
-    thigh_ik = bpy.props.StringProperty(name="Thigh IK Name")
-    shin_ik  = bpy.props.StringProperty(name="Shin IK Name")
-    foot_ik  = bpy.props.StringProperty(name="Foot IK Name")
-    footroll = bpy.props.StringProperty(name="Foot Roll Name")
-    pole     = bpy.props.StringProperty(name="Pole IK Name")
-    mfoot_ik = bpy.props.StringProperty(name="MFoot IK Name")
+    thigh_fk: StringProperty(name="Thigh FK Name")
+    shin_fk:  StringProperty(name="Shin FK Name")
+    mfoot_fk: StringProperty(name="MFoot FK Name")
+    foot_fk:  StringProperty(name="Foot FK Name", default="")
+    thigh_ik: StringProperty(name="Thigh IK Name")
+    shin_ik:  StringProperty(name="Shin IK Name")
+    foot_ik:  StringProperty(name="Foot IK Name")
+    footroll: StringProperty(name="Foot Roll Name")
+    pole:     StringProperty(name="Pole IK Name")
+    mfoot_ik: StringProperty(name="MFoot IK Name")
 
-    main_parent = bpy.props.StringProperty(name="Main Parent", default="")
+    main_parent: StringProperty(name="Main Parent", default="")
 
     @classmethod
     def poll(cls, context):
         return (context.active_object != None and context.mode == 'POSE')
 
     def execute(self, context):
-        use_global_undo = context.user_preferences.edit.use_global_undo
-        context.user_preferences.edit.use_global_undo = False
-        try:
-            ik2fk_leg(context.active_object, fk=[self.thigh_fk, self.shin_fk, self.mfoot_fk, self.foot_fk], ik=[self.thigh_ik, self.shin_ik, self.foot_ik, self.footroll, self.pole, self.mfoot_ik, self.main_parent])
-        finally:
-            context.user_preferences.edit.use_global_undo = use_global_undo
+        ik2fk_leg(context.active_object, fk=[self.thigh_fk, self.shin_fk, self.mfoot_fk, self.foot_fk], ik=[self.thigh_ik, self.shin_ik, self.foot_ik, self.footroll, self.pole, self.mfoot_ik, self.main_parent])
         return {'FINISHED'}
+''']
 
+REGISTER_OP_POLE = ['Rigify_Rot2PoleSwitch']
+
+UTILITIES_OP_POLE = ['''
 ###########################
 ## IK Rotation Pole Snap ##
 ###########################
@@ -726,13 +742,14 @@ class Rigify_Rot2PoleSwitch(bpy.types.Operator):
     bl_idname = "pose.rigify_rot2pole_" + rig_id
     bl_label = "Rotation - Pole toggle"
     bl_description = "Toggles IK chain between rotation and pole target"
-    bone_name = bpy.props.StringProperty(default='')
-    limb_type = bpy.props.StringProperty(name="Limb Type")
-    controls = bpy.props.StringProperty(name="Controls string")
-    ik_ctrl = bpy.props.StringProperty(name="IK Controls string")
-    fk_ctrl = bpy.props.StringProperty(name="FK Controls string")
-    parent = bpy.props.StringProperty(name="Parent name")
-    pole = bpy.props.StringProperty(name="Pole name")
+
+    bone_name: StringProperty(default='')
+    limb_type: StringProperty(name="Limb Type")
+    controls: StringProperty(name="Controls string")
+    ik_ctrl: StringProperty(name="IK Controls string")
+    fk_ctrl: StringProperty(name="FK Controls string")
+    parent: StringProperty(name="Parent name")
+    pole: StringProperty(name="Pole name")
 
     def execute(self, context):
         rig = context.object
@@ -743,7 +760,47 @@ class Rigify_Rot2PoleSwitch(bpy.types.Operator):
 
         rotPoleToggle(rig, self.limb_type, self.controls, self.ik_ctrl, self.fk_ctrl, self.parent, self.pole)
         return {'FINISHED'}
+''']
 
+REGISTER_RIG_ARM = REGISTER_OP_ARM_FKIK + REGISTER_OP_POLE
+
+UTILITIES_RIG_ARM = [
+    *UTILITIES_FUNC_ARM_FKIK,
+    *UTILITIES_FUNC_POLE,
+    *UTILITIES_OP_ARM_FKIK,
+    *UTILITIES_OP_POLE,
+]
+
+REGISTER_RIG_LEG = REGISTER_OP_LEG_FKIK + REGISTER_OP_POLE
+
+UTILITIES_RIG_LEG = [
+    *UTILITIES_FUNC_LEG_FKIK,
+    *UTILITIES_FUNC_POLE,
+    *UTILITIES_OP_LEG_FKIK,
+    *UTILITIES_OP_POLE,
+]
+
+##############################
+## Default set of utilities ##
+##############################
+
+UI_REGISTER = [
+    'RigUI',
+    'RigLayers',
+    *REGISTER_OP_ARM_FKIK,
+    *REGISTER_OP_LEG_FKIK,
+]
+
+# Include arm and leg utilities for now in case somebody wants to use
+# legacy limb rigs, which expect these to be available by default.
+UI_UTILITIES = [
+    *UTILITIES_FUNC_ARM_FKIK,
+    *UTILITIES_FUNC_LEG_FKIK,
+    *UTILITIES_OP_ARM_FKIK,
+    *UTILITIES_OP_LEG_FKIK,
+]
+
+UI_SLIDERS = '''
 ###################
 ## Rig UI Panels ##
 ###################
@@ -752,7 +809,8 @@ class RigUI(bpy.types.Panel):
     bl_space_type = 'VIEW_3D'
     bl_region_type = 'UI'
     bl_label = "Rig Main Properties"
-    bl_idname = rig_id + "_PT_rig_ui"
+    bl_idname = "VIEW3D_PT_rig_ui_" + rig_id
+    bl_category = 'Item'
 
     @classmethod
     def poll(self, context):
@@ -795,7 +853,8 @@ class RigLayers(bpy.types.Panel):
     bl_space_type = 'VIEW_3D'
     bl_region_type = 'UI'
     bl_label = "Rig Layers"
-    bl_idname = rig_id + "_PT_rig_layers"
+    bl_idname = "VIEW3D_PT_rig_layers_" + rig_id
+    bl_category = 'Item'
 
     @classmethod
     def poll(self, context):
@@ -837,27 +896,3 @@ class RigLayers(bpy.types.Panel):
     code += "        row.prop(context.active_object.data, 'layers', index=28, toggle=True, text='Root')\n"
 
     return code
-
-
-UI_REGISTER = '''
-
-def register():
-    bpy.utils.register_class(Rigify_Arm_FK2IK)
-    bpy.utils.register_class(Rigify_Arm_IK2FK)
-    bpy.utils.register_class(Rigify_Leg_FK2IK)
-    bpy.utils.register_class(Rigify_Leg_IK2FK)
-    bpy.utils.register_class(Rigify_Rot2PoleSwitch)
-    bpy.utils.register_class(RigUI)
-    bpy.utils.register_class(RigLayers)
-
-def unregister():
-    bpy.utils.unregister_class(Rigify_Arm_FK2IK)
-    bpy.utils.unregister_class(Rigify_Arm_IK2FK)
-    bpy.utils.unregister_class(Rigify_Leg_FK2IK)
-    bpy.utils.unregister_class(Rigify_Leg_IK2FK)
-    bpy.utils.register_class(Rigify_Rot2PoleSwitch)
-    bpy.utils.unregister_class(RigUI)
-    bpy.utils.unregister_class(RigLayers)
-
-register()
-'''
