@@ -19,10 +19,16 @@
 # <pep8 compliant>
 
 import bpy
-from bpy.props import StringProperty
+from bpy.props import (
+    BoolProperty,
+    IntProperty,
+    EnumProperty,
+    StringProperty
+)
+
 from mathutils import Color
 
-from .utils import get_rig_type, MetarigError
+from .utils import MetarigError
 from .utils import write_metarig, write_widget
 from .utils import unique_name
 from .utils import upgradeMetarigTypes, outdated_types
@@ -32,6 +38,18 @@ from .rigs.utils import get_limb_generated_names
 from . import rig_lists
 from . import generate
 from . import rot_mode
+from . import feature_set_list
+
+
+def build_type_list(context, rigify_types):
+    rigify_types.clear()
+
+    for r in sorted(rig_lists.rigs):
+        if (context.object.data.active_feature_set in ('all', rig_lists.rigs[r]['feature_set'])
+                or len(feature_set_list.feature_set_items(context.scene, context)) == 2
+                ):
+            a = rigify_types.add()
+            a.name = r
 
 
 class DATA_PT_rigify_buttons(bpy.types.Panel):
@@ -59,21 +77,18 @@ class DATA_PT_rigify_buttons(bpy.types.Panel):
 
             check_props = ['IK_follow', 'root/parent', 'FK_limb_follow', 'IK_Stretch']
 
-            for obj in bpy.data.objects:
-                if type(obj.data) != bpy.types.Armature:
-                    continue
-                for bone in obj.pose.bones:
-                    if bone.bone.layers[30] and (list(set(bone.keys()) & set(check_props))):
-                        show_warning = True
+            for bone in obj.pose.bones:
+                if bone.bone.layers[30] and (list(set(bone.keys()) & set(check_props))):
+                    show_warning = True
+                    break
+            for b in obj.pose.bones:
+                if b.rigify_type in outdated_types.keys():
+                    if outdated_types[b.rigify_type]:
+                        show_update_metarig = True
+                    else:
+                        show_update_metarig = False
+                        show_not_updatable = True
                         break
-                for b in obj.pose.bones:
-                    if b.rigify_type in outdated_types.keys():
-                        if outdated_types[b.rigify_type]:
-                            show_update_metarig = True
-                        else:
-                            show_update_metarig = False
-                            show_not_updatable = True
-                            break
 
             if show_warning:
                 layout.label(text=WARNING, icon='ERROR')
@@ -89,11 +104,19 @@ class DATA_PT_rigify_buttons(bpy.types.Panel):
             if show_update_metarig:
 
                 layout.label(text="This metarig contains old rig-types that can be automatically upgraded to benefit of rigify's new features.", icon='ERROR')
-                layout.label(text= "To use it as-is you need to enable legacy mode.",)
+                layout.label(text="To use it as-is you need to enable legacy mode.",)
                 layout.operator("pose.rigify_upgrade_types", text="Upgrade Metarig")
 
             row = layout.row()
+            # Rig type field
+
+            col = layout.column(align=True)
+            col.active = (not 'rig_id' in C.object.data)
+
+            col.separator()
+            row = col.row()
             row.operator("pose.rigify_generate", text="Generate Rig", icon='POSE_HLT')
+
             row.enabled = enable_generate_and_advanced
 
             if id_store.rigify_advanced_generation:
@@ -111,7 +134,7 @@ class DATA_PT_rigify_buttons(bpy.types.Panel):
                 row = col.row(align=True)
                 row.prop(id_store, "rigify_generate_mode", expand=True)
 
-                main_row = col.row(align=True).split(percentage=0.3)
+                main_row = col.row(align=True).split(factor=0.3)
                 col1 = main_row.column()
                 col2 = main_row.column()
                 col1.label(text="Rig Name")
@@ -156,24 +179,15 @@ class DATA_PT_rigify_buttons(bpy.types.Panel):
 
         elif obj.mode == 'EDIT':
             # Build types list
-            collection_name = str(id_store.rigify_collection).replace(" ", "")
+            build_type_list(context, id_store.rigify_types)
 
-            for i in range(0, len(id_store.rigify_types)):
-                id_store.rigify_types.remove(0)
-
-            for r in rig_lists.rig_list:
-
-                if collection_name == "All":
-                    a = id_store.rigify_types.add()
-                    a.name = r
-                elif r.startswith(collection_name + '.'):
-                    a = id_store.rigify_types.add()
-                    a.name = r
-                elif (collection_name == "None") and ("." not in r):
-                    a = id_store.rigify_types.add()
-                    a.name = r
+            if id_store.rigify_active_type > len(id_store.rigify_types):
+                id_store.rigify_active_type = 0
 
             # Rig type list
+            if len(feature_set_list.feature_set_items(context.scene, context)) > 2:
+                row = layout.row()
+                row.prop(context.object.data, "active_feature_set")
             row = layout.row()
             row.template_list("UI_UL_list", "rigify_types", id_store, "rigify_types", id_store, 'rigify_active_type')
 
@@ -208,14 +222,14 @@ class DATA_PT_rigify_layer_names(bpy.types.Panel):
                 return
 
         # UI
-        main_row = layout.row(align=True).split(0.05)
+        main_row = layout.row(align=True).split(factor=0.05)
         col1 = main_row.column()
         col2 = main_row.column()
         col1.label()
         for i in range(32):
             if i == 16 or i == 29:
                 col1.label()
-            col1.label(str(i+1) + '.')
+            col1.label(text=str(i+1) + '.')
 
         for i, rigify_layer in enumerate(arm.rigify_layers):
             # note: rigify_layer == arm.rigify_layers[i]
@@ -234,8 +248,8 @@ class DATA_PT_rigify_layer_names(bpy.types.Panel):
                 #row.prop(arm, "layers", index=i, text="Layer %d" % (i + 1), toggle=True, icon=icon)
                 row.prop(rigify_layer, "name", text="")
                 row.prop(rigify_layer, "row", text="UI Row")
-                icon = 'RADIOBUT_ON' if rigify_layer.set else 'RADIOBUT_OFF'
-                row.prop(rigify_layer, "set", text="", toggle=True, icon=icon)
+                icon = 'RADIOBUT_ON' if rigify_layer.selset else 'RADIOBUT_OFF'
+                row.prop(rigify_layer, "selset", text="", toggle=True, icon=icon)
                 row.prop(rigify_layer, "group", text="Bone Group")
             else:
                 row = col.row(align=True)
@@ -247,8 +261,8 @@ class DATA_PT_rigify_layer_names(bpy.types.Panel):
                 row1.prop(rigify_layer, "name", text="")
                 row1.prop(rigify_layer, "row", text="UI Row")
                 row1.enabled = False
-                icon = 'RADIOBUT_ON' if rigify_layer.set else 'RADIOBUT_OFF'
-                row.prop(rigify_layer, "set", text="", toggle=True, icon=icon)
+                icon = 'RADIOBUT_ON' if rigify_layer.selset else 'RADIOBUT_OFF'
+                row.prop(rigify_layer, "selset", text="", toggle=True, icon=icon)
                 row.prop(rigify_layer, "group", text="Bone Group")
             if rigify_layer.group == 0:
                 row.label(text='None')
@@ -324,8 +338,8 @@ class DATA_OT_rigify_use_standard_colors(bpy.types.Operator):
         if not hasattr(armature, 'rigify_colors'):
             return {'FINISHED'}
 
-        current_theme = bpy.context.user_preferences.themes.items()[0][0]
-        theme = bpy.context.user_preferences.themes[current_theme]
+        current_theme = bpy.context.preferences.themes.items()[0][0]
+        theme = bpy.context.preferences.themes[current_theme]
 
         armature.rigify_selection_colors.select = theme.view_3d.bone_pose
         armature.rigify_selection_colors.active = theme.view_3d.bone_pose_active
@@ -351,8 +365,8 @@ class DATA_OT_rigify_apply_selection_colors(bpy.types.Operator):
         if not hasattr(armature, 'rigify_colors'):
             return {'FINISHED'}
 
-        #current_theme = bpy.context.user_preferences.themes.items()[0][0]
-        #theme = bpy.context.user_preferences.themes[current_theme]
+        #current_theme = bpy.context.preferences.themes.items()[0][0]
+        #theme = bpy.context.preferences.themes[current_theme]
 
         for col in armature.rigify_colors:
             col.select = armature.rigify_selection_colors.select
@@ -377,8 +391,8 @@ class DATA_OT_rigify_bone_group_add(bpy.types.Operator):
             armature.rigify_colors.add()
             armature.rigify_colors[-1].name = unique_name(armature.rigify_colors, 'Group')
 
-            current_theme = bpy.context.user_preferences.themes.items()[0][0]
-            theme = bpy.context.user_preferences.themes[current_theme]
+            current_theme = bpy.context.preferences.themes.items()[0][0]
+            theme = bpy.context.preferences.themes[current_theme]
 
             armature.rigify_colors[-1].normal = theme.view_3d.wire
             armature.rigify_colors[-1].normal.hsv = theme.view_3d.wire.hsv
@@ -395,28 +409,29 @@ class DATA_OT_rigify_bone_group_add_theme(bpy.types.Operator):
     bl_label = "Rigify Add Bone Group color set from Theme"
     bl_options = {"REGISTER", "UNDO"}
 
-    theme = bpy.props.EnumProperty(items=(('THEME01', 'THEME01', ''),
-                                          ('THEME02', 'THEME02', ''),
-                                          ('THEME03', 'THEME03', ''),
-                                          ('THEME04', 'THEME04', ''),
-                                          ('THEME05', 'THEME05', ''),
-                                          ('THEME06', 'THEME06', ''),
-                                          ('THEME07', 'THEME07', ''),
-                                          ('THEME08', 'THEME08', ''),
-                                          ('THEME09', 'THEME09', ''),
-                                          ('THEME10', 'THEME10', ''),
-                                          ('THEME11', 'THEME11', ''),
-                                          ('THEME12', 'THEME12', ''),
-                                          ('THEME13', 'THEME13', ''),
-                                          ('THEME14', 'THEME14', ''),
-                                          ('THEME15', 'THEME15', ''),
-                                          ('THEME16', 'THEME16', ''),
-                                          ('THEME17', 'THEME17', ''),
-                                          ('THEME18', 'THEME18', ''),
-                                          ('THEME19', 'THEME19', ''),
-                                          ('THEME20', 'THEME20', '')
-                                          ),
-                                   name='Theme')
+    theme: EnumProperty(items=(
+        ('THEME01', 'THEME01', ''),
+        ('THEME02', 'THEME02', ''),
+        ('THEME03', 'THEME03', ''),
+        ('THEME04', 'THEME04', ''),
+        ('THEME05', 'THEME05', ''),
+        ('THEME06', 'THEME06', ''),
+        ('THEME07', 'THEME07', ''),
+        ('THEME08', 'THEME08', ''),
+        ('THEME09', 'THEME09', ''),
+        ('THEME10', 'THEME10', ''),
+        ('THEME11', 'THEME11', ''),
+        ('THEME12', 'THEME12', ''),
+        ('THEME13', 'THEME13', ''),
+        ('THEME14', 'THEME14', ''),
+        ('THEME15', 'THEME15', ''),
+        ('THEME16', 'THEME16', ''),
+        ('THEME17', 'THEME17', ''),
+        ('THEME18', 'THEME18', ''),
+        ('THEME19', 'THEME19', ''),
+        ('THEME20', 'THEME20', '')
+        ),
+         name='Theme')
 
     @classmethod
     def poll(cls, context):
@@ -435,7 +450,7 @@ class DATA_OT_rigify_bone_group_add_theme(bpy.types.Operator):
 
             id = int(self.theme[-2:]) - 1
 
-            theme_color_set = bpy.context.user_preferences.themes[0].bone_color_sets[id]
+            theme_color_set = bpy.context.preferences.themes[0].bone_color_sets[id]
 
             armature.rigify_colors[-1].normal = theme_color_set.normal
             armature.rigify_colors[-1].select = theme_color_set.select
@@ -448,7 +463,7 @@ class DATA_OT_rigify_bone_group_remove(bpy.types.Operator):
     bl_idname = "armature.rigify_bone_group_remove"
     bl_label = "Rigify Remove Bone Group color set"
 
-    idx = bpy.props.IntProperty()
+    idx: IntProperty()
 
     @classmethod
     def poll(cls, context):
@@ -492,9 +507,9 @@ class DATA_OT_rigify_bone_group_remove_all(bpy.types.Operator):
 class DATA_UL_rigify_bone_groups(bpy.types.UIList):
     def draw_item(self, context, layout, data, item, icon, active_data, active_propname, index):
         row = layout.row(align=True)
-        row = row.split(percentage=0.1)
+        row = row.split(factor=0.1)
         row.label(text=str(index+1))
-        row = row.split(percentage=0.7)
+        row = row.split(factor=0.7)
         row.prop(item, "name", text='', emboss=False)
         row = row.row(align=True)
         icon = 'LOCKED' if item.standard_colors_lock else 'UNLOCKED'
@@ -507,7 +522,7 @@ class DATA_UL_rigify_bone_groups(bpy.types.UIList):
         row2.enabled = not bpy.context.object.data.rigify_colors_lock
 
 
-class DATA_PT_rigify_bone_groups_specials(bpy.types.Menu):
+class DATA_MT_rigify_bone_groups_context_menu(bpy.types.Menu):
     bl_label = 'Rigify Bone Groups Specials'
 
     def draw(self, context):
@@ -547,9 +562,9 @@ class DATA_PT_rigify_bone_groups(bpy.types.Panel):
         row.template_list("DATA_UL_rigify_bone_groups", "", obj.data, "rigify_colors", obj.data, "rigify_colors_index")
 
         col = row.column(align=True)
-        col.operator("armature.rigify_bone_group_add", icon='ZOOMIN', text="")
-        col.operator("armature.rigify_bone_group_remove", icon='ZOOMOUT', text="").idx = obj.data.rigify_colors_index
-        col.menu("DATA_PT_rigify_bone_groups_specials", icon='DOWNARROW_HLT', text="")
+        col.operator("armature.rigify_bone_group_add", icon='ZOOM_IN', text="")
+        col.operator("armature.rigify_bone_group_remove", icon='ZOOM_OUT', text="").idx = obj.data.rigify_colors_index
+        col.menu("DATA_MT_rigify_bone_groups_context_menu", icon='DOWNARROW_HLT', text="")
         row = layout.row()
         row.prop(armature, 'rigify_theme_to_add', text = 'Theme')
         op = row.operator("armature.rigify_bone_group_add_theme", text="Add From Theme")
@@ -575,38 +590,24 @@ class BONE_PT_rigify_buttons(bpy.types.Panel):
         C = context
         id_store = C.window_manager
         bone = context.active_pose_bone
-        collection_name = str(id_store.rigify_collection).replace(" ", "")
         rig_name = str(context.active_pose_bone.rigify_type).replace(" ", "")
 
         layout = self.layout
 
         # Build types list
-        for i in range(0, len(id_store.rigify_types)):
-            id_store.rigify_types.remove(0)
-
-        for r in rig_lists.rig_list:
-            if r in rig_lists.implementation_rigs:
-                continue
-            # collection = r.split('.')[0]  # UNUSED
-            if collection_name == "All":
-                a = id_store.rigify_types.add()
-                a.name = r
-            elif r.startswith(collection_name + '.'):
-                a = id_store.rigify_types.add()
-                a.name = r
-            elif collection_name == "None" and len(r.split('.')) == 1:
-                a = id_store.rigify_types.add()
-                a.name = r
+        build_type_list(context, id_store.rigify_types)
 
         # Rig type field
+        if len(feature_set_list.feature_set_items(context.scene, context)) > 2:
+            row = layout.row()
+            row.prop(context.object.data, "active_feature_set")
         row = layout.row()
-        row.prop_search(bone, "rigify_type", id_store, "rigify_types", text="Rig type:")
+        row.prop_search(bone, "rigify_type", id_store, "rigify_types", text="Rig type")
 
         # Rig type parameters / Rig type non-exist alert
         if rig_name != "":
             try:
-                rig = get_rig_type(rig_name)
-                rig.Rig
+                rig = rig_lists.rigs[rig_name]['module']
             except (ImportError, AttributeError):
                 row = layout.row()
                 box = row.box()
@@ -626,9 +627,13 @@ class BONE_PT_rigify_buttons(bpy.types.Panel):
 
 class VIEW3D_PT_tools_rigify_dev(bpy.types.Panel):
     bl_label = "Rigify Dev Tools"
-    bl_category = 'Tools'
     bl_space_type = 'VIEW_3D'
-    bl_region_type = 'TOOLS'
+    bl_region_type = 'UI'
+    bl_category = 'View'
+
+    @classmethod
+    def poll(cls, context):
+        return context.mode in ['EDIT_ARMATURE', 'EDIT_MESH']
 
     @classmethod
     def poll(cls, context):
@@ -650,14 +655,15 @@ class VIEW3D_PT_tools_rigify_dev(bpy.types.Panel):
 
 class VIEW3D_PT_rigify_animation_tools(bpy.types.Panel):
     bl_label = "Rigify Animation Tools"
-    bl_category = 'Tools'
     bl_context = "posemode"
     bl_space_type = 'VIEW_3D'
-    bl_region_type = 'TOOLS'
+    bl_region_type = 'UI'
+    bl_category = 'View'
 
     @classmethod
     def poll(cls, context):
-        return context.object.type == 'ARMATURE' and context.active_object.data.get("rig_id") is not None
+        return context.object and context.object.type == 'ARMATURE'\
+               and context.active_object.data.get("rig_id") is not None
 
     def draw(self, context):
         obj = context.active_object
@@ -681,8 +687,8 @@ class VIEW3D_PT_rigify_animation_tools(bpy.types.Panel):
             row.operator("rigify.transfer_ik_to_fk", text='FK2IK Action', icon='ACTION_TWEAK')
 
             row = self.layout.row(align=True)
-            row.operator("rigify.clear_animation", text="Clear IK Action", icon='CANCEL').type = "IK"
-            row.operator("rigify.clear_animation", text="Clear FK Action", icon='CANCEL').type = "FK"
+            row.operator("rigify.clear_animation", text="Clear IK Action", icon='CANCEL').anim_type = "IK"
+            row.operator("rigify.clear_animation", text="Clear FK Action", icon='CANCEL').anim_type = "FK"
 
             row = self.layout.row(align=True)
             op = row.operator("rigify.rotation_pole", icon='FORCE_HARMONIC', text='Switch to pole')
@@ -726,7 +732,7 @@ class LayerInit(bpy.types.Operator):
 
     bl_idname = "pose.rigify_layer_init"
     bl_label = "Add Rigify Layers"
-    bl_options = {'UNDO'}
+    bl_options = {'UNDO', 'INTERNAL'}
 
     def execute(self, context):
         obj = context.object
@@ -743,21 +749,17 @@ class Generate(bpy.types.Operator):
 
     bl_idname = "pose.rigify_generate"
     bl_label = "Rigify Generate Rig"
-    bl_options = {'UNDO'}
+    bl_options = {'UNDO', 'INTERNAL'}
     bl_description = 'Generates a rig from the active metarig armature'
 
     def execute(self, context):
         import importlib
         importlib.reload(generate)
 
-        use_global_undo = context.user_preferences.edit.use_global_undo
-        context.user_preferences.edit.use_global_undo = False
         try:
             generate.generate_rig(context, context.object)
         except MetarigError as rig_exception:
             rigify_report_exception(self, rig_exception)
-        finally:
-            context.user_preferences.edit.use_global_undo = use_global_undo
 
         return {'FINISHED'}
 
@@ -783,43 +785,39 @@ class SwitchToLegacy(bpy.types.Operator):
     bl_idname = "pose.rigify_switch_to_legacy"
     bl_label = "Legacy Mode will disable Rigify new features"
     bl_description = 'Switches Rigify to Legacy Mode'
-    bl_options = {'UNDO'}
+    bl_options = {'UNDO', 'INTERNAL'}
 
     def invoke(self, context, event):
         return context.window_manager.invoke_confirm(self, event)
 
     def execute(self, context):
-        bpy.context.user_preferences.addons['rigify'].preferences.legacy_mode = True
+        bpy.context.preferences.addons['rigify'].preferences.legacy_mode = True
         return {'FINISHED'}
 
 
 class Sample(bpy.types.Operator):
-    """Create a sample metarig to be modified before generating """ \
-    """the final rig"""
+    """Create a sample metarig to be modified before generating the final rig"""
 
     bl_idname = "armature.metarig_sample_add"
     bl_label = "Add a sample metarig for a rig type"
-    bl_options = {'UNDO'}
+    bl_options = {'UNDO', 'INTERNAL'}
 
-    metarig_type = StringProperty(
-            name="Type",
-            description="Name of the rig type to generate a sample of",
-            maxlen=128,
-            )
+    metarig_type: StringProperty(
+        name="Type",
+        description="Name of the rig type to generate a sample of",
+        maxlen=128,
+    )
 
     def execute(self, context):
         if context.mode == 'EDIT_ARMATURE' and self.metarig_type != "":
-            use_global_undo = context.user_preferences.edit.use_global_undo
-            context.user_preferences.edit.use_global_undo = False
             try:
-                rig = get_rig_type(self.metarig_type)
+                rig = rig_lists.rigs[self.metarig_type]["module"]
                 create_sample = rig.create_sample
             except (ImportError, AttributeError):
                 raise Exception("rig type '" + self.metarig_type + "' has no sample.")
             else:
                 create_sample(context.active_object)
             finally:
-                context.user_preferences.edit.use_global_undo = use_global_undo
                 bpy.ops.object.mode_set(mode='EDIT')
 
         return {'FINISHED'}
@@ -1074,20 +1072,20 @@ def IktoFk(rig, window='ALL'):
                 break
 
 
-def clearAnimation(act, type, names):
+def clearAnimation(act, anim_type, names):
 
     bones = []
     for group in names:
         if names[group]['limb_type'] == 'arm':
-            if type == 'IK':
+            if anim_type == 'IK':
                 bones.extend([names[group]['controls'][0], names[group]['controls'][4]])
-            elif type == 'FK':
+            elif anim_type == 'FK':
                 bones.extend([names[group]['controls'][1], names[group]['controls'][2], names[group]['controls'][3]])
         else:
-            if type == 'IK':
+            if anim_type == 'IK':
                 bones.extend([names[group]['controls'][0], names[group]['controls'][6], names[group]['controls'][5],
                               names[group]['controls'][4]])
-            elif type == 'FK':
+            elif anim_type == 'FK':
                 bones.extend([names[group]['controls'][1], names[group]['controls'][2], names[group]['controls'][3],
                               names[group]['controls'][4]])
     FCurves = []
@@ -1214,6 +1212,7 @@ class OBJECT_OT_IK2FK(bpy.types.Operator):
     bl_idname = "rigify.ik2fk"
     bl_label = "IK2FK"
     bl_description = "Snaps IK limb on FK"
+    bl_options = {'INTERNAL'}
 
     def execute(self,context):
         rig = context.object
@@ -1229,6 +1228,7 @@ class OBJECT_OT_FK2IK(bpy.types.Operator):
     bl_idname = "rigify.fk2ik"
     bl_label = "FK2IK"
     bl_description = "Snaps FK limb on IK"
+    bl_options = {'INTERNAL'}
 
     def execute(self,context):
         rig = context.object
@@ -1243,6 +1243,7 @@ class OBJECT_OT_TransferFKtoIK(bpy.types.Operator):
     bl_idname = "rigify.transfer_fk_to_ik"
     bl_label = "Transfer FK anim to IK"
     bl_description = "Transfer FK animation to IK bones"
+    bl_options = {'INTERNAL'}
 
     def execute(self, context):
         rig = context.object
@@ -1258,6 +1259,7 @@ class OBJECT_OT_TransferIKtoFK(bpy.types.Operator):
     bl_idname = "rigify.transfer_ik_to_fk"
     bl_label = "Transfer IK anim to FK"
     bl_description = "Transfer IK animation to FK bones"
+    bl_options = {'INTERNAL'}
 
     def execute(self, context):
         rig = context.object
@@ -1271,24 +1273,20 @@ class OBJECT_OT_ClearAnimation(bpy.types.Operator):
     bl_idname = "rigify.clear_animation"
     bl_label = "Clear Animation"
     bl_description = "Clear Animation For FK or IK Bones"
-    type = StringProperty()
+    bl_options = {'INTERNAL'}
+
+    anim_type: StringProperty()
 
     def execute(self, context):
+        rig = context.object
+        scn = context.scene
+        if not rig.animation_data:
+            return {'FINISHED'}
+        act = rig.animation_data.action
+        if not act:
+            return {'FINISHED'}
 
-        use_global_undo = context.user_preferences.edit.use_global_undo
-        context.user_preferences.edit.use_global_undo = False
-        try:
-            rig = context.object
-            scn = context.scene
-            if not rig.animation_data:
-                return {'FINISHED'}
-            act = rig.animation_data.action
-            if not act:
-                return {'FINISHED'}
-
-            clearAnimation(act, self.type, names=get_limb_generated_names(rig))
-        finally:
-            context.user_preferences.edit.use_global_undo = use_global_undo
+        clearAnimation(act, self.anim_type, names=get_limb_generated_names(rig))
         return {'FINISHED'}
 
 
@@ -1296,11 +1294,13 @@ class OBJECT_OT_Rot2Pole(bpy.types.Operator):
     bl_idname = "rigify.rotation_pole"
     bl_label = "Rotation - Pole toggle"
     bl_description = "Toggles IK chain between rotation and pole target"
-    bone_name = bpy.props.StringProperty(default='')
-    window = bpy.props.StringProperty(default='ALL')
-    toggle = bpy.props.BoolProperty(default=True)
-    value = bpy.props.BoolProperty(default=True)
-    bake = bpy.props.BoolProperty(default=True)
+    bl_options = {'INTERNAL'}
+
+    bone_name: StringProperty(default='')
+    window: StringProperty(default='ALL')
+    toggle: BoolProperty(default=True)
+    value: BoolProperty(default=True)
+    bake: BoolProperty(default=True)
 
     def execute(self, context):
         rig = context.object
@@ -1313,74 +1313,60 @@ class OBJECT_OT_Rot2Pole(bpy.types.Operator):
         return {'FINISHED'}
 
 
+### Registering ###
+
+
+classes = (
+    DATA_OT_rigify_add_bone_groups,
+    DATA_OT_rigify_use_standard_colors,
+    DATA_OT_rigify_apply_selection_colors,
+    DATA_OT_rigify_bone_group_add,
+    DATA_OT_rigify_bone_group_add_theme,
+    DATA_OT_rigify_bone_group_remove,
+    DATA_OT_rigify_bone_group_remove_all,
+    DATA_UL_rigify_bone_groups,
+    DATA_MT_rigify_bone_groups_context_menu,
+    DATA_PT_rigify_bone_groups,
+    DATA_PT_rigify_layer_names,
+    DATA_PT_rigify_buttons,
+    BONE_PT_rigify_buttons,
+    VIEW3D_PT_rigify_animation_tools,
+    VIEW3D_PT_tools_rigify_dev,
+    LayerInit,
+    Generate,
+    UpgradeMetarigTypes,
+    SwitchToLegacy,
+    Sample,
+    EncodeMetarig,
+    EncodeMetarigSample,
+    EncodeWidget,
+    OBJECT_OT_GetFrameRange,
+    OBJECT_OT_FK2IK,
+    OBJECT_OT_IK2FK,
+    OBJECT_OT_TransferFKtoIK,
+    OBJECT_OT_TransferIKtoFK,
+    OBJECT_OT_ClearAnimation,
+    OBJECT_OT_Rot2Pole,
+)
+
+
 def register():
+    from bpy.utils import register_class
 
-    bpy.utils.register_class(DATA_OT_rigify_add_bone_groups)
-    bpy.utils.register_class(DATA_OT_rigify_use_standard_colors)
-    bpy.utils.register_class(DATA_OT_rigify_apply_selection_colors)
-    bpy.utils.register_class(DATA_OT_rigify_bone_group_add)
-    bpy.utils.register_class(DATA_OT_rigify_bone_group_add_theme)
-    bpy.utils.register_class(DATA_OT_rigify_bone_group_remove)
-    bpy.utils.register_class(DATA_OT_rigify_bone_group_remove_all)
-    bpy.utils.register_class(DATA_UL_rigify_bone_groups)
-    bpy.utils.register_class(DATA_PT_rigify_bone_groups_specials)
-    bpy.utils.register_class(DATA_PT_rigify_bone_groups)
-    bpy.utils.register_class(DATA_PT_rigify_layer_names)
-    bpy.utils.register_class(DATA_PT_rigify_buttons)
-    bpy.utils.register_class(BONE_PT_rigify_buttons)
-    bpy.utils.register_class(VIEW3D_PT_rigify_animation_tools)
-    bpy.utils.register_class(VIEW3D_PT_tools_rigify_dev)
-    bpy.utils.register_class(LayerInit)
-    bpy.utils.register_class(Generate)
-    bpy.utils.register_class(UpgradeMetarigTypes)
-    bpy.utils.register_class(SwitchToLegacy)
-    bpy.utils.register_class(Sample)
-    bpy.utils.register_class(EncodeMetarig)
-    bpy.utils.register_class(EncodeMetarigSample)
-    bpy.utils.register_class(EncodeWidget)
-    bpy.utils.register_class(OBJECT_OT_GetFrameRange)
-    bpy.utils.register_class(OBJECT_OT_FK2IK)
-    bpy.utils.register_class(OBJECT_OT_IK2FK)
-    bpy.utils.register_class(OBJECT_OT_TransferFKtoIK)
-    bpy.utils.register_class(OBJECT_OT_TransferIKtoFK)
-    bpy.utils.register_class(OBJECT_OT_ClearAnimation)
-    bpy.utils.register_class(OBJECT_OT_Rot2Pole)
+    # Classes.
+    for cls in classes:
+        register_class(cls)
 
+    # Sub-modules.
     rot_mode.register()
 
 
 def unregister():
+    from bpy.utils import unregister_class
 
-    bpy.utils.unregister_class(DATA_OT_rigify_add_bone_groups)
-    bpy.utils.unregister_class(DATA_OT_rigify_use_standard_colors)
-    bpy.utils.unregister_class(DATA_OT_rigify_apply_selection_colors)
-    bpy.utils.unregister_class(DATA_OT_rigify_bone_group_add)
-    bpy.utils.unregister_class(DATA_OT_rigify_bone_group_add_theme)
-    bpy.utils.unregister_class(DATA_OT_rigify_bone_group_remove)
-    bpy.utils.unregister_class(DATA_OT_rigify_bone_group_remove_all)
-    bpy.utils.unregister_class(DATA_UL_rigify_bone_groups)
-    bpy.utils.unregister_class(DATA_PT_rigify_bone_groups_specials)
-    bpy.utils.unregister_class(DATA_PT_rigify_bone_groups)
-    bpy.utils.unregister_class(DATA_PT_rigify_layer_names)
-    bpy.utils.unregister_class(DATA_PT_rigify_buttons)
-    bpy.utils.unregister_class(BONE_PT_rigify_buttons)
-    bpy.utils.unregister_class(VIEW3D_PT_rigify_animation_tools)
-    bpy.utils.unregister_class(VIEW3D_PT_tools_rigify_dev)
-    bpy.utils.unregister_class(LayerInit)
-    bpy.utils.unregister_class(Generate)
-    bpy.utils.unregister_class(UpgradeMetarigTypes)
-    bpy.utils.unregister_class(SwitchToLegacy)
-    bpy.utils.unregister_class(Sample)
-    bpy.utils.unregister_class(EncodeMetarig)
-    bpy.utils.unregister_class(EncodeMetarigSample)
-    bpy.utils.unregister_class(EncodeWidget)
-    bpy.utils.unregister_class(OBJECT_OT_GetFrameRange)
-    bpy.utils.unregister_class(OBJECT_OT_FK2IK)
-    bpy.utils.unregister_class(OBJECT_OT_IK2FK)
-    bpy.utils.unregister_class(OBJECT_OT_TransferFKtoIK)
-    bpy.utils.unregister_class(OBJECT_OT_TransferIKtoFK)
-    bpy.utils.unregister_class(OBJECT_OT_ClearAnimation)
-    bpy.utils.unregister_class(OBJECT_OT_Rot2Pole)
-
+    # Sub-modules.
     rot_mode.unregister()
 
+    # Classes.
+    for cls in classes:
+        unregister_class(cls)
