@@ -120,8 +120,11 @@ def check(check_ctxt, msgs, key, msgsrc, settings):
            key[1][0].isalpha() and not key[1][0].isupper()):
             not_capitalized.add(key)
     if end_point is not None:
-        if (key[1].strip().endswith('.') and not key[1].strip().endswith('...') and
-            key[1] not in settings.WARN_MSGID_END_POINT_ALLOWED):
+        if (
+                key[1].strip().endswith('.') and
+                (not key[1].strip().endswith('...')) and
+                key[1] not in settings.WARN_MSGID_END_POINT_ALLOWED
+        ):
             end_point.add(key)
     if undoc_ops is not None:
         if key[1] == settings.UNDOC_OPS_STR:
@@ -183,8 +186,10 @@ def print_info(reports, pot):
 #                if py_in_rna and key in py_in_rna:
 #                    _print("\t\t-> RNA message also used in py UI code!")
                 if spell_errors and spell_errors.get(key):
-                    lines = ["\t\t-> {}: misspelled, suggestions are ({})".format(w, "'" + "', '".join(errs) + "'")
-                             for w, errs in  spell_errors[key]]
+                    lines = [
+                        "\t\t-> {}: misspelled, suggestions are ({})".format(w, "'" + "', '".join(errs) + "'")
+                        for w, errs in spell_errors[key]
+                    ]
                     _print("\n".join(lines))
             _print("\t\t{}".format("\n\t\t".join(pot.msgs[key].sources)))
 
@@ -215,18 +220,20 @@ def dump_rna_messages(msgs, reports, settings, verbose=False):
     """
     def class_blacklist():
         blacklist_rna_class = {getattr(bpy.types, cls_id) for cls_id in (
-                # core classes
-                "Context", "Event", "Function", "UILayout", "UnknownType", "Property", "Struct",
-                # registerable classes
-                "Panel", "Menu", "Header", "RenderEngine", "Operator", "OperatorMacro", "Macro", "KeyingSetInfo",
-                # window classes
-                "Window",
-            )
+            # core classes
+            "Context", "Event", "Function", "UILayout", "UnknownType", "Property", "Struct",
+            # registerable classes
+            "Panel", "Menu", "Header", "RenderEngine", "Operator", "OperatorMacro", "Macro", "KeyingSetInfo",
+            # window classes
+            "Window",
+        )
         }
 
         # More builtin classes we don't need to parse.
         blacklist_rna_class |= {cls for cls in bpy.types.Property.__subclasses__()}
 
+        # None of this seems needed anymore, and it's broken anyway with current master (blender 2.79.1)...
+        """
         _rna = {getattr(bpy.types, cls) for cls in dir(bpy.types)}
 
         # Classes which are attached to collections can be skipped too, these are api access only.
@@ -241,7 +248,7 @@ def dump_rna_messages(msgs, reports, settings, verbose=False):
         # Now here is the *ugly* hack!
         # Unfortunately, all classes we want to access are not available from bpy.types (OperatorProperties subclasses
         # are not here, as they have the same name as matching Operator ones :( ). So we use __subclasses__() calls
-        # to walk through all rna hierachy.
+        # to walk through all rna hierarchy.
         # But unregistered classes remain listed by relevant __subclasses__() calls (be it a Py or BPY/RNA bug),
         # and obviously the matching RNA struct exists no more, so trying to access their data (even the identifier)
         # quickly leads to segfault!
@@ -276,6 +283,7 @@ def dump_rna_messages(msgs, reports, settings, verbose=False):
             #op = get_instance(idname)
             #if 'INTERNAL' in path_resolve(op, "bl_options"):
                 #blacklist_rna_class.add(idname)
+        """
 
         return blacklist_rna_class
 
@@ -343,6 +351,35 @@ def dump_rna_messages(msgs, reports, settings, verbose=False):
                         process_msg(msgs, default_context, item.description, msgsrc, reports, check_ctxt_rna_tip,
                                     settings)
 
+    def walk_tools_definitions(cls):
+        from bl_ui.space_toolsystem_common import ToolDef
+
+        bl_rna = cls.bl_rna
+        op_default_context = bpy.app.translations.contexts.operator_default
+
+        def process_tooldef(tool_context, tool):
+            if not isinstance(tool, ToolDef):
+                if callable(tool):
+                    for t in tool(None):
+                        process_tooldef(tool_context, t)
+                return
+            msgsrc = "bpy.types.{} Tools: '{}', '{}'".format(bl_rna.identifier, tool_context, tool.idname)
+            if tool.label:
+                process_msg(msgs, op_default_context, tool.label, msgsrc, reports, check_ctxt_rna, settings)
+            # Callable (function) descriptions must handle their translations themselves.
+            if tool.description and not callable(tool.description):
+                process_msg(msgs, default_context, tool.description, msgsrc, reports, check_ctxt_rna_tip, settings)
+
+        for tool_context, tools_defs in cls.tools_all():
+            for tools_group in tools_defs:
+                if tools_group is None:
+                    continue
+                elif isinstance(tools_group, tuple) and not isinstance(tools_group, ToolDef):
+                    for tool in tools_group:
+                        process_tooldef(tool_context, tool)
+                else:
+                    process_tooldef(tool_context, tools_group)
+
     blacklist_rna_class = class_blacklist()
 
     def walk_class(cls):
@@ -365,24 +402,30 @@ def dump_rna_messages(msgs, reports, settings, verbose=False):
         if hasattr(bl_rna, 'bl_label') and bl_rna.bl_label:
             process_msg(msgs, msgctxt, bl_rna.bl_label, msgsrc, reports, check_ctxt_rna, settings)
 
+        # Tools Panels definitions.
+        if hasattr(bl_rna, 'tools_all') and bl_rna.tools_all:
+            walk_tools_definitions(cls)
+
         walk_properties(cls)
 
     def walk_keymap_hierarchy(hier, msgsrc_prev):
         km_i18n_context = bpy.app.translations.contexts.id_windowmanager
         for lvl in hier:
             msgsrc = msgsrc_prev + "." + lvl[1]
-            process_msg(msgs, km_i18n_context, lvl[0], msgsrc, reports, None, settings)
+            if isinstance(lvl[0], str):  # Can be a function too, now, with tool system...
+                process_msg(msgs, km_i18n_context, lvl[0], msgsrc, reports, None, settings)
             if lvl[3]:
                 walk_keymap_hierarchy(lvl[3], msgsrc)
 
     # Dump Messages
     operator_categories = {}
+
     def process_cls_list(cls_list):
         if not cls_list:
             return
 
         def full_class_id(cls):
-            """Gives us 'ID.Lamp.AreaLamp' which is best for sorting."""
+            """Gives us 'ID.Light.AreaLight' which is best for sorting."""
             # Always the same issue, some classes listed in blacklist should actually no more exist (they have been
             # unregistered), but are still listed by __subclasses__() calls... :/
             if cls in blacklist_rna_class:
@@ -428,8 +471,8 @@ def dump_rna_messages(msgs, reports, settings, verbose=False):
                     reports, check_ctxt_rna, settings)
 
     # And parse keymaps!
-    from bpy_extras.keyconfig_utils import KM_HIERARCHY
-    walk_keymap_hierarchy(KM_HIERARCHY, "KM_HIERARCHY")
+    from bl_keymap_utils import keymap_hierarchy
+    walk_keymap_hierarchy(keymap_hierarchy.generate(), "KM_HIERARCHY")
 
 
 ##### Python source code #####
@@ -444,6 +487,7 @@ def dump_py_messages_from_files(msgs, reports, files, settings):
     i18n_contexts = bpy.app.translations.contexts
 
     root_paths = tuple(bpy.utils.resource_path(t) for t in ('USER', 'LOCAL', 'SYSTEM'))
+
     def make_rel(path):
         for rp in root_paths:
             if path.startswith(rp):
@@ -488,7 +532,7 @@ def dump_py_messages_from_files(msgs, reports, files, settings):
     def extract_strings_split(node):
         """
         Returns a list args as returned by 'extract_strings()', but split into groups based on separate_nodes, this way
-        expressions like ("A" if test else "B") wont be merged but "A" + "B" will.
+        expressions like ("A" if test else "B") won't be merged but "A" + "B" will.
         """
         estr_ls = []
         nds_ls = []
@@ -507,6 +551,7 @@ def dump_py_messages_from_files(msgs, reports, files, settings):
         return [_extract_string_merge(estr_ls, nds_ls) for estr_ls, nds_ls in bag]
 
     i18n_ctxt_ids = {v for v in bpy.app.translations.contexts_C_to_py.values()}
+
     def _ctxt_to_ctxt(node):
         # We must try, to some extend, to get contexts from vars instead of only literal strings...
         ctxt = extract_strings(node)[0]
@@ -524,7 +569,7 @@ def dump_py_messages_from_files(msgs, reports, files, settings):
 
     def _op_to_ctxt(node):
         # Some smart coders like things like:
-        #    >>> row.operator("wm.addon_disable" if is_enabled else "wm.addon_enable", ...)
+        #    >>> row.operator("preferences.addon_disable" if is_enabled else "preferences.addon_enable", ...)
         # We only take first arg into account here!
         bag = extract_strings_split(node)
         opname, _ = bag[0]
@@ -534,7 +579,7 @@ def dump_py_messages_from_files(msgs, reports, files, settings):
         for n in opname.split('.'):
             op = getattr(op, n)
         try:
-            return op.get_rna().bl_rna.translation_context
+            return op.get_rna_type().translation_context
         except Exception as e:
             default_op_context = i18n_contexts.operator_default
             print("ERROR: ", str(e))
@@ -558,9 +603,9 @@ def dump_py_messages_from_files(msgs, reports, files, settings):
     translate_kw = {
         "text": ((("text_ctxt",), _ctxt_to_ctxt),
                  (("operator",), _op_to_ctxt),
-                ),
-        "msgid": ((("msgctxt",), _ctxt_to_ctxt),
                  ),
+        "msgid": ((("msgctxt",), _ctxt_to_ctxt),
+                  ),
         "message": (),
     }
 
@@ -608,7 +653,7 @@ def dump_py_messages_from_files(msgs, reports, files, settings):
         func_translate_args[func_id] = pgettext_variants_args
         for func_id in func_ids:
             func_translate_args[func_id] = pgettext_variants_args
-    #print(func_translate_args)
+    # print(func_translate_args)
 
     # Break recursive nodes look up on some kind of nodes.
     # E.g. we don't want to get strings inside subscripts (blah["foo"])!
@@ -663,7 +708,7 @@ def dump_py_messages_from_files(msgs, reports, files, settings):
                                 if kw.arg == arg_kw:
                                     context_elements[arg_kw] = kw.value
                                     break
-                    #print(context_elements)
+                    # print(context_elements)
                     for kws, proc in translate_kw[msgid]:
                         if set(kws) <= context_elements.keys():
                             args = tuple(context_elements[k] for k in kws)
@@ -673,7 +718,7 @@ def dump_py_messages_from_files(msgs, reports, files, settings):
                                 msgctxts[msgid] = ctxt
                                 break
 
-                #print(translate_args)
+                # print(translate_args)
                 # do nothing if not found
                 for arg_kw, (arg_pos, _) in func_args.items():
                     msgctxt = msgctxts[arg_kw]
@@ -703,7 +748,7 @@ def dump_py_messages(msgs, reports, addons, settings, addons_only=False):
             return []
         if os.path.isdir(path):
             return [os.path.join(dpath, fn) for dpath, _, fnames in os.walk(path) for fn in fnames
-                                            if not fn.startswith("_") and fn.endswith(".py")]
+                    if not fn.startswith("_") and fn.endswith(".py")]
         return [path]
 
     files = []
@@ -735,7 +780,9 @@ def dump_src_messages(msgs, reports, settings):
     pygettexts = tuple(re.compile(r).search for r in settings.PYGETTEXT_KEYWORDS)
 
     _clean_str = re.compile(settings.str_clean_re).finditer
-    clean_str = lambda s: "".join(m.group("clean") for m in _clean_str(s))
+
+    def clean_str(s):
+        return "".join(m.group("clean") for m in _clean_str(s))
 
     def dump_src_file(path, rel_path, msgs, reports, settings):
         def process_entry(_msgctxt, _msgid):
@@ -870,10 +917,10 @@ def dump_messages(do_messages, do_checks, settings):
         process_msg(msgs, settings.DEFAULT_CONTEXT, cat[1],
                     "Language categories’ labels from bl_i18n_utils/settings.py", reports, None, settings)
 
-    #pot.check()
+    # pot.check()
     pot.unescape()  # Strings gathered in py/C source code may contain escaped chars...
     print_info(reports, pot)
-    #pot.check()
+    # pot.check()
 
     if do_messages:
         print("Writing messages…")
@@ -974,7 +1021,7 @@ def main():
     args = parser.parse_args(argv)
 
     settings = settings_i18n.I18nSettings()
-    settings.from_json(args.settings)
+    settings.load(args.settings)
 
     if args.output:
         settings.FILE_NAME_POT = args.output
