@@ -34,15 +34,18 @@ _modules = [
     "properties_data_camera",
     "properties_data_curve",
     "properties_data_empty",
-    "properties_data_lamp",
+    "properties_data_gpencil",
+    "properties_data_light",
     "properties_data_lattice",
     "properties_data_mesh",
     "properties_data_metaball",
     "properties_data_modifier",
+    "properties_data_shaderfx",
+    "properties_data_lightprobe",
     "properties_data_speaker",
-    "properties_game",
     "properties_mask_common",
     "properties_material",
+    "properties_material_gpencil",
     "properties_object",
     "properties_paint_common",
     "properties_grease_pencil_common",
@@ -57,10 +60,18 @@ _modules = [
     "properties_physics_smoke",
     "properties_physics_softbody",
     "properties_render",
-    "properties_render_layer",
+    "properties_output",
+    "properties_view_layer",
     "properties_scene",
     "properties_texture",
     "properties_world",
+
+    # Generic Space Modules
+    #
+    # Depends on DNA_WORKSPACE_TOOL (C define).
+    "space_toolsystem_common",
+    "space_toolsystem_toolbar",
+
     "space_clip",
     "space_console",
     "space_dopesheet",
@@ -68,18 +79,22 @@ _modules = [
     "space_graph",
     "space_image",
     "space_info",
-    "space_logic",
     "space_nla",
     "space_node",
     "space_outliner",
     "space_properties",
     "space_sequencer",
+    "space_statusbar",
     "space_text",
     "space_time",
+    "space_topbar",
     "space_userpref",
     "space_view3d",
     "space_view3d_toolbar",
-    ]
+
+    # XXX, keep last so panels show after all other tool options.
+    "properties_workspace",
+]
 
 import bpy
 
@@ -99,17 +114,21 @@ def register():
             register_class(cls)
 
     # space_userprefs.py
-    from bpy.props import StringProperty, EnumProperty
+    from bpy.props import (
+        EnumProperty,
+        StringProperty,
+    )
     from bpy.types import WindowManager
 
-    def addon_filter_items(self, context):
+    def addon_filter_items(_self, _context):
         import addon_utils
 
-        items = [('All', "All", "All Add-ons"),
-                 ('User', "User", "All Add-ons Installed by User"),
-                 ('Enabled', "Enabled", "All Enabled Add-ons"),
-                 ('Disabled', "Disabled", "All Disabled Add-ons"),
-                 ]
+        items = [
+            ('All', "All", "All Add-ons"),
+            ('User', "User", "All Add-ons Installed by User"),
+            ('Enabled', "Enabled", "All Enabled Add-ons"),
+            ('Disabled', "Disabled", "All Disabled Add-ons"),
+        ]
 
         items_unique = set()
 
@@ -121,26 +140,27 @@ def register():
         return items
 
     WindowManager.addon_search = StringProperty(
-            name="Search",
-            description="Search within the selected filter",
-            options={'TEXTEDIT_UPDATE'},
-            )
+        name="Search",
+        description="Search within the selected filter",
+        options={'TEXTEDIT_UPDATE'},
+    )
     WindowManager.addon_filter = EnumProperty(
-            items=addon_filter_items,
-            name="Category",
-            description="Filter add-ons by category",
-            )
+        items=addon_filter_items,
+        name="Category",
+        description="Filter add-ons by category",
+    )
 
     WindowManager.addon_support = EnumProperty(
-            items=[('OFFICIAL', "Official", "Officially supported"),
-                   ('COMMUNITY', "Community", "Maintained by community developers"),
-                   ('TESTING', "Testing", "Newly contributed scripts (excluded from release builds)")
-                   ],
-            name="Support",
-            description="Display support level",
-            default={'OFFICIAL', 'COMMUNITY'},
-            options={'ENUM_FLAG'},
-            )
+        items=[
+            ('OFFICIAL', "Official", "Officially supported"),
+            ('COMMUNITY', "Community", "Maintained by community developers"),
+            ('TESTING', "Testing", "Newly contributed scripts (excluded from release builds)")
+        ],
+        name="Support",
+        description="Display support level",
+        default={'OFFICIAL', 'COMMUNITY'},
+        options={'ENUM_FLAG'},
+    )
     # done...
 
 
@@ -153,6 +173,8 @@ def unregister():
 
 # Define a default UIList, when a list does not need any custom drawing...
 # Keep in sync with its #defined name in UI_interface.h
+
+
 class UI_UL_list(bpy.types.UIList):
     # These are common filtering or ordering operations (same as the default C ones!).
     @staticmethod
