@@ -1,6 +1,4 @@
 /*
- * ***** BEGIN GPL LICENSE BLOCK *****
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -14,10 +12,10 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation,
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * Contributor(s): Esteban Tovagliari, Cedric Paille, Kevin Dietrich
- *
- * ***** END GPL LICENSE BLOCK *****
+ */
+
+/** \file
+ * \ingroup balembic
  */
 
 #ifndef __ABC_ALEMBIC_H__
@@ -27,55 +25,56 @@
 extern "C" {
 #endif
 
-struct bContext;
 struct CacheReader;
-struct DerivedMesh;
 struct ListBase;
+struct Mesh;
 struct Object;
 struct Scene;
+struct bContext;
 
 typedef struct AbcArchiveHandle AbcArchiveHandle;
 
 enum {
-	ABC_ARCHIVE_OGAWA = 0,
-	ABC_ARCHIVE_HDF5  = 1,
+  ABC_ARCHIVE_OGAWA = 0,
+  ABC_ARCHIVE_HDF5 = 1,
 };
 
 int ABC_get_version(void);
 
 struct AlembicExportParams {
-	double frame_start;
-	double frame_end;
+  double frame_start;
+  double frame_end;
 
-	unsigned int frame_samples_xform;
-	unsigned int frame_samples_shape;
+  unsigned int frame_samples_xform;
+  unsigned int frame_samples_shape;
 
-	double shutter_open;
-	double shutter_close;
+  double shutter_open;
+  double shutter_close;
 
-	bool selected_only;
-	bool uvs;
-	bool normals;
-	bool vcolors;
-	bool apply_subdiv;
-	bool flatten_hierarchy;
-	bool visible_layers_only;
-	bool renderable_only;
-	bool face_sets;
-	bool use_subdiv_schema;
-	bool packuv;
-	bool triangulate;
-	bool export_hair;
-	bool export_particles;
+  bool selected_only;
+  bool uvs;
+  bool normals;
+  bool vcolors;
+  bool apply_subdiv;
+  bool curves_as_mesh;
+  bool flatten_hierarchy;
+  bool visible_layers_only;
+  bool renderable_only;
+  bool face_sets;
+  bool use_subdiv_schema;
+  bool packuv;
+  bool triangulate;
+  bool export_hair;
+  bool export_particles;
 
-	unsigned int compression_type : 1;
+  unsigned int compression_type : 1;
 
-	/* See MOD_TRIANGULATE_NGON_xxx and MOD_TRIANGULATE_QUAD_xxx
-	 * in DNA_modifier_types.h */
-	int quad_method;
-	int ngon_method;
+  /* See MOD_TRIANGULATE_NGON_xxx and MOD_TRIANGULATE_QUAD_xxx
+   * in DNA_modifier_types.h */
+  int quad_method;
+  int ngon_method;
 
-	float global_scale;
+  float global_scale;
 };
 
 /* The ABC_export and ABC_import functions both take a as_background_job
@@ -88,12 +87,11 @@ struct AlembicExportParams {
  * true when the export was ok, and false if there were any errors.
  */
 
-bool ABC_export(
-        struct Scene *scene,
-        struct bContext *C,
-        const char *filepath,
-        const struct AlembicExportParams *params,
-        bool as_background_job);
+bool ABC_export(struct Scene *scene,
+                struct bContext *C,
+                const char *filepath,
+                const struct AlembicExportParams *params,
+                bool as_background_job);
 
 bool ABC_import(struct bContext *C,
                 const char *filepath,
@@ -109,17 +107,15 @@ AbcArchiveHandle *ABC_create_handle(const char *filename, struct ListBase *objec
 
 void ABC_free_handle(AbcArchiveHandle *handle);
 
-void ABC_get_transform(struct CacheReader *reader,
-                       float r_mat[4][4],
-                       float time,
-                       float scale);
+void ABC_get_transform(struct CacheReader *reader, float r_mat[4][4], float time, float scale);
 
-struct DerivedMesh *ABC_read_mesh(struct CacheReader *reader,
-                                  struct Object *ob,
-                                  struct DerivedMesh *dm,
-                                  const float time,
-                                  const char **err_str,
-                                  int flags);
+/* Either modifies current_mesh in-place or constructs a new mesh. */
+struct Mesh *ABC_read_mesh(struct CacheReader *reader,
+                           struct Object *ob,
+                           struct Mesh *current_mesh,
+                           const float time,
+                           const char **err_str,
+                           int flags);
 
 void CacheReader_incref(struct CacheReader *reader);
 void CacheReader_free(struct CacheReader *reader);
@@ -133,4 +129,4 @@ struct CacheReader *CacheReader_open_alembic_object(struct AbcArchiveHandle *han
 }
 #endif
 
-#endif  /* __ABC_ALEMBIC_H__ */
+#endif /* __ABC_ALEMBIC_H__ */
