@@ -1,6 +1,4 @@
 /*
- * ***** BEGIN GPL LICENSE BLOCK *****
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -17,17 +15,11 @@
  *
  * The Original Code is Copyright (C) 2006 Blender Foundation.
  * All rights reserved.
- *
- * The Original Code is: all of this file.
- *
- * Contributor(s): Ben Batt <benbatt@gmail.com>
- *
- * ***** END GPL LICENSE BLOCK *****
  */
 
-/** \file BKE_cdderivedmesh.h
- *  \ingroup bke
- *  \section aboutcdderivedmesh CDDerivedMesh interface
+/** \file
+ * \ingroup bke
+ * \section aboutcdderivedmesh CDDerivedMesh interface
  *   CDDerivedMesh (CD = Custom Data) is a DerivedMesh backend which stores
  *   mesh elements (vertices, edges and faces) as layers of custom element data.
  */
@@ -36,16 +28,17 @@
 #define __BKE_CDDERIVEDMESH_H__
 
 #include "BKE_DerivedMesh.h"
+#include "BKE_customdata.h"
 
-struct DerivedMesh;
 struct BMEditMesh;
-struct Mesh;
+struct CustomData_MeshMasks;
+struct DerivedMesh;
 struct MLoopNorSpaceArray;
+struct Mesh;
 struct Object;
 
 /* creates a new CDDerivedMesh */
-struct DerivedMesh *CDDM_new(int numVerts, int numEdges, int numFaces,
-                             int numLoops, int numPolys);
+struct DerivedMesh *CDDM_new(int numVerts, int numEdges, int numFaces, int numLoops, int numPolys);
 
 /* creates a CDDerivedMesh from the given Mesh, this will reference the
  * original data in Mesh, but it is safe to apply vertex coordinates or
@@ -53,19 +46,17 @@ struct DerivedMesh *CDDM_new(int numVerts, int numEdges, int numFaces,
  * data to not overwrite the original */
 struct DerivedMesh *CDDM_from_mesh(struct Mesh *mesh);
 
+/* creates a CDDerivedMesh from the given Mesh with custom allocation type. */
+struct DerivedMesh *CDDM_from_mesh_ex(struct Mesh *mesh,
+                                      eCDAllocType alloctype,
+                                      const struct CustomData_MeshMasks *mask);
+
 struct DerivedMesh *CDDM_from_bmesh(struct BMesh *bm, const bool use_mdisps);
 
 /* creates a CDDerivedMesh from the given BMEditMesh */
-DerivedMesh *CDDM_from_editbmesh(struct BMEditMesh *em, const bool use_mdisps, const bool use_tessface);
-
-/* merge verts  */
-/* Enum for merge_mode of CDDM_merge_verts.
- * Refer to cdderivedmesh.c for details. */
-enum {
-	CDDM_MERGE_VERTS_DUMP_IF_MAPPED,
-	CDDM_MERGE_VERTS_DUMP_IF_EQUAL,
-};
-DerivedMesh *CDDM_merge_verts(DerivedMesh *dm, const int *vtargetmap, const int tot_vtargetmap, const int merge_mode);
+DerivedMesh *CDDM_from_editbmesh(struct BMEditMesh *em,
+                                 const bool use_mdisps,
+                                 const bool use_tessface);
 
 /* creates a CDDerivedMesh from the given curve object */
 struct DerivedMesh *CDDM_from_curve(struct Object *ob);
@@ -78,27 +69,24 @@ DerivedMesh *CDDM_from_curve_displist(struct Object *ob, struct ListBase *dispba
  * custom element data.
  */
 struct DerivedMesh *CDDM_copy(struct DerivedMesh *dm);
-struct DerivedMesh *CDDM_copy_from_tessface(struct DerivedMesh *dm);
-struct DerivedMesh *CDDM_copy_with_tessface(struct DerivedMesh *dm);
 
 /* creates a CDDerivedMesh with the same layer stack configuration as the
  * given DerivedMesh and containing the requested numbers of elements.
  * elements are initialized to all zeros
  */
-struct DerivedMesh *CDDM_from_template_ex(
-        struct DerivedMesh *source,
-        int numVerts, int numEdges, int numFaces,
-        int numLoops, int numPolys,
-        CustomDataMask mask);
-struct DerivedMesh *CDDM_from_template(
-        struct DerivedMesh *source,
-        int numVerts, int numEdges, int numFaces,
-        int numLoops, int numPolys);
-
-/* converts mfaces to mpolys.  note things may break if there are not valid
- * medges surrounding each mface.
- */
-void CDDM_tessfaces_to_faces(struct DerivedMesh *dm);
+struct DerivedMesh *CDDM_from_template_ex(struct DerivedMesh *source,
+                                          int numVerts,
+                                          int numEdges,
+                                          int numFaces,
+                                          int numLoops,
+                                          int numPolys,
+                                          const struct CustomData_MeshMasks *mask);
+struct DerivedMesh *CDDM_from_template(struct DerivedMesh *source,
+                                       int numVerts,
+                                       int numEdges,
+                                       int numFaces,
+                                       int numLoops,
+                                       int numPolys);
 
 /* applies vertex coordinates or normals to a CDDerivedMesh. if the MVert
  * layer is a referenced layer, it will be duplicate to not overwrite the
@@ -112,22 +100,15 @@ void CDDM_apply_vert_normals(struct DerivedMesh *cddm, short (*vertNormals)[3]);
 void CDDM_calc_normals_mapping_ex(struct DerivedMesh *dm, const bool only_face_normals);
 void CDDM_calc_normals_mapping(struct DerivedMesh *dm);
 void CDDM_calc_normals(struct DerivedMesh *dm);
-void CDDM_calc_normals_tessface(struct DerivedMesh *dm);
 
-void CDDM_calc_loop_normals(struct DerivedMesh *dm, const bool use_split_normals, const float split_angle);
-void CDDM_calc_loop_normals_spacearr(struct DerivedMesh *dm, const bool use_split_normals, const float split_angle,
+void CDDM_calc_loop_normals(struct DerivedMesh *dm,
+                            const bool use_split_normals,
+                            const float split_angle);
+void CDDM_calc_loop_normals_spacearr(struct DerivedMesh *dm,
+                                     const bool use_split_normals,
+                                     const float split_angle,
                                      struct MLoopNorSpaceArray *r_lnors_spacearr);
 
-/* calculates edges for a CDDerivedMesh (from face data)
- * this completely replaces the current edge data in the DerivedMesh
- * builds edges from the tessellated face data.
- */
-void CDDM_calc_edges_tessface(struct DerivedMesh *dm);
-
-/* same as CDDM_calc_edges_tessface only makes edges from ngon faces instead of tessellation
- * faces*/
-void CDDM_calc_edges(struct DerivedMesh *dm);
-
 /* reconstitute face triangulation */
 void CDDM_recalc_tessellation(struct DerivedMesh *dm);
 void CDDM_recalc_tessellation_ex(struct DerivedMesh *dm, const bool do_face_nor_cpy);
@@ -174,4 +155,3 @@ void CDDM_set_mloop(struct DerivedMesh *dm, struct MLoop *mloop);
 void CDDM_set_mpoly(struct DerivedMesh *dm, struct MPoly *mpoly);
 
 #endif
-
