@@ -1,6 +1,4 @@
 /*
- * ***** BEGIN GPL LICENSE BLOCK *****
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -17,62 +15,73 @@
  *
  * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
  * All rights reserved.
- *
- * The Original Code is: all of this file.
- *
- * Contributor(s): none yet.
- *
- * ***** END GPL LICENSE BLOCK *****
  */
 
 #ifndef __BKE_WRITEFFMPEG_H__
 #define __BKE_WRITEFFMPEG_H__
 
-/** \file BKE_writeffmpeg.h
- *  \ingroup bke
+/** \file
+ * \ingroup bke
  */
 
 #ifdef WITH_FFMPEG
 
-#ifdef __cplusplus
+#  ifdef __cplusplus
 extern "C" {
-#endif
+#  endif
 
 enum {
-	FFMPEG_MPEG1    = 0,
-	FFMPEG_MPEG2    = 1,
-	FFMPEG_MPEG4    = 2,
-	FFMPEG_AVI      = 3,
-	FFMPEG_MOV      = 4,
-	FFMPEG_DV       = 5,
-	FFMPEG_H264     = 6,
-	FFMPEG_XVID     = 7,
-	FFMPEG_FLV      = 8,
-	FFMPEG_MKV      = 9,
-	FFMPEG_OGG      = 10,
-	FFMPEG_INVALID  = 11,
+  FFMPEG_MPEG1 = 0,
+  FFMPEG_MPEG2 = 1,
+  FFMPEG_MPEG4 = 2,
+  FFMPEG_AVI = 3,
+  FFMPEG_MOV = 4,
+  FFMPEG_DV = 5,
+  FFMPEG_H264 = 6,
+  FFMPEG_XVID = 7,
+  FFMPEG_FLV = 8,
+  FFMPEG_MKV = 9,
+  FFMPEG_OGG = 10,
+  FFMPEG_INVALID = 11,
 };
 
 enum {
-	FFMPEG_PRESET_NONE      = 0,
-	FFMPEG_PRESET_DVD       = 1,
-	FFMPEG_PRESET_SVCD      = 2,
-	FFMPEG_PRESET_VCD       = 3,
-	FFMPEG_PRESET_DV        = 4,
-	FFMPEG_PRESET_H264      = 5,
-	FFMPEG_PRESET_THEORA    = 6,
-	FFMPEG_PRESET_XVID      = 7,
+  FFMPEG_PRESET_NONE = 0,
+  FFMPEG_PRESET_DVD = 1,
+  FFMPEG_PRESET_SVCD = 2,
+  FFMPEG_PRESET_VCD = 3,
+  FFMPEG_PRESET_DV = 4,
+  FFMPEG_PRESET_H264 = 5,
+  FFMPEG_PRESET_THEORA = 6,
+  FFMPEG_PRESET_XVID = 7,
 };
 
 struct RenderData;
 struct ReportList;
 struct Scene;
 
-int BKE_ffmpeg_start(void *context_v, struct Scene *scene, struct RenderData *rd, int rectx, int recty, struct ReportList *reports, bool preview, const char *suffix);
+int BKE_ffmpeg_start(void *context_v,
+                     struct Scene *scene,
+                     struct RenderData *rd,
+                     int rectx,
+                     int recty,
+                     struct ReportList *reports,
+                     bool preview,
+                     const char *suffix);
 void BKE_ffmpeg_end(void *context_v);
-int BKE_ffmpeg_append(void *context_v, struct RenderData *rd, int start_frame, int frame, int *pixels,
-                      int rectx, int recty, const char *suffix, struct ReportList *reports);
-void BKE_ffmpeg_filepath_get(char *string, struct RenderData *rd, bool preview, const char *suffix);
+int BKE_ffmpeg_append(void *context_v,
+                      struct RenderData *rd,
+                      int start_frame,
+                      int frame,
+                      int *pixels,
+                      int rectx,
+                      int recty,
+                      const char *suffix,
+                      struct ReportList *reports);
+void BKE_ffmpeg_filepath_get(char *string,
+                             struct RenderData *rd,
+                             bool preview,
+                             const char *suffix);
 
 void BKE_ffmpeg_preset_set(struct RenderData *rd, int preset);
 void BKE_ffmpeg_image_type_verify(struct RenderData *rd, struct ImageFormatData *imf);
@@ -85,11 +94,10 @@ void BKE_ffmpeg_property_del(struct RenderData *rd, void *type, void *prop_);
 void *BKE_ffmpeg_context_create(void);
 void BKE_ffmpeg_context_free(void *context_v);
 
-#ifdef __cplusplus
+#  ifdef __cplusplus
 }
-#endif
+#  endif
 
 #endif
 
 #endif
-
