@@ -1,6 +1,4 @@
 /*
- * ***** BEGIN GPL LICENSE BLOCK *****
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -17,24 +15,18 @@
  *
  * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
  * All rights reserved.
- *
- * The Original Code is: all of this file.
- *
- * Contributor(s): none yet.
- *
- * ***** END GPL LICENSE BLOCK *****
- *
  */
 
 #ifndef __BLI_RECT_H__
 #define __BLI_RECT_H__
 
-/** \file BLI_rect.h
- *  \ingroup bli
+/** \file
+ * \ingroup bli
  */
 
 #include "DNA_vec_types.h"
-#include "BLI_utildefines.h"
+#include "BLI_sys_types.h" /* bool */
+#include "BLI_compiler_compat.h"
 
 struct rctf;
 struct rcti;
@@ -54,7 +46,13 @@ void BLI_rctf_init_minmax(struct rctf *rect);
 void BLI_rcti_do_minmax_v(struct rcti *rect, const int xy[2]);
 void BLI_rctf_do_minmax_v(struct rctf *rect, const float xy[2]);
 
-void BLI_rctf_transform_pt_v(const rctf *dst, const rctf *src, float xy_dst[2], const float xy_src[2]);
+void BLI_rctf_transform_pt_v(const rctf *dst,
+                             const rctf *src,
+                             float xy_dst[2],
+                             const float xy_src[2]);
+void BLI_rctf_transform_calc_m4_pivot_min_ex(
+    const rctf *dst, const rctf *src, float matrix[4][4], uint x, uint y);
+void BLI_rctf_transform_calc_m4_pivot_min(const rctf *dst, const rctf *src, float matrix[4][4]);
 
 void BLI_rctf_translate(struct rctf *rect, float x, float y);
 void BLI_rcti_translate(struct rcti *rect, int x, int y);
@@ -64,8 +62,15 @@ void BLI_rcti_resize(struct rcti *rect, int x, int y);
 void BLI_rctf_resize(struct rctf *rect, float x, float y);
 void BLI_rcti_scale(rcti *rect, const float scale);
 void BLI_rctf_scale(rctf *rect, const float scale);
-void BLI_rctf_interp(struct rctf *rect, const struct rctf *rect_a, const struct rctf *rect_b, const float fac);
-//void BLI_rcti_interp(struct rctf *rect, struct rctf *rect_a, struct rctf *rect_b, float fac);
+void BLI_rctf_pad_y(struct rctf *rect,
+                    const float boundary_size,
+                    const float pad_min,
+                    const float pad_max);
+void BLI_rctf_interp(struct rctf *rect,
+                     const struct rctf *rect_a,
+                     const struct rctf *rect_b,
+                     const float fac);
+// void BLI_rcti_interp(struct rctf *rect, struct rctf *rect_a, struct rctf *rect_b, float fac);
 bool BLI_rctf_clamp_pt_v(const struct rctf *rect, float xy[2]);
 bool BLI_rcti_clamp_pt_v(const struct rcti *rect, int xy[2]);
 bool BLI_rctf_clamp(struct rctf *rect, const struct rctf *rect_bounds, float r_xy[2]);
@@ -90,8 +95,8 @@ bool BLI_rcti_isect_segment(const struct rcti *rect, const int s1[2], const int
 bool BLI_rctf_isect_segment(const struct rctf *rect, const float s1[2], const float s2[2]);
 bool BLI_rcti_isect_circle(const struct rcti *rect, const float xy[2], const float radius);
 bool BLI_rctf_isect_circle(const struct rctf *rect, const float xy[2], const float radius);
-bool BLI_rcti_inside_rcti(rcti *rct_a, const rcti *rct_b);
-bool BLI_rctf_inside_rctf(rctf *rct_a, const rctf *rct_b);
+bool BLI_rcti_inside_rcti(const rcti *rct_a, const rcti *rct_b);
+bool BLI_rctf_inside_rctf(const rctf *rct_a, const rctf *rct_b);
 void BLI_rcti_union(struct rcti *rcti1, const struct rcti *rcti2);
 void BLI_rctf_union(struct rctf *rctf1, const struct rctf *rctf2);
 void BLI_rcti_rctf_copy(struct rcti *dst, const struct rctf *src);
@@ -107,20 +112,50 @@ void print_rcti(const char *str, const struct rcti *rect);
 #define print_rctf_id(rect) print_rctf(STRINGIFY(rect), rect)
 #define print_rcti_id(rect) print_rcti(STRINGIFY(rect), rect)
 
-BLI_INLINE float BLI_rcti_cent_x_fl(const struct rcti *rct) { return (float)(rct->xmin + rct->xmax) / 2.0f; }
-BLI_INLINE float BLI_rcti_cent_y_fl(const struct rcti *rct) { return (float)(rct->ymin + rct->ymax) / 2.0f; }
-BLI_INLINE int   BLI_rcti_cent_x(const struct rcti *rct) { return (rct->xmin + rct->xmax) / 2; }
-BLI_INLINE int   BLI_rcti_cent_y(const struct rcti *rct) { return (rct->ymin + rct->ymax) / 2; }
-BLI_INLINE float BLI_rctf_cent_x(const struct rctf *rct) { return (rct->xmin + rct->xmax) / 2.0f; }
-BLI_INLINE float BLI_rctf_cent_y(const struct rctf *rct) { return (rct->ymin + rct->ymax) / 2.0f; }
+BLI_INLINE float BLI_rcti_cent_x_fl(const struct rcti *rct)
+{
+  return (float)(rct->xmin + rct->xmax) / 2.0f;
+}
+BLI_INLINE float BLI_rcti_cent_y_fl(const struct rcti *rct)
+{
+  return (float)(rct->ymin + rct->ymax) / 2.0f;
+}
+BLI_INLINE int BLI_rcti_cent_x(const struct rcti *rct)
+{
+  return (rct->xmin + rct->xmax) / 2;
+}
+BLI_INLINE int BLI_rcti_cent_y(const struct rcti *rct)
+{
+  return (rct->ymin + rct->ymax) / 2;
+}
+BLI_INLINE float BLI_rctf_cent_x(const struct rctf *rct)
+{
+  return (rct->xmin + rct->xmax) / 2.0f;
+}
+BLI_INLINE float BLI_rctf_cent_y(const struct rctf *rct)
+{
+  return (rct->ymin + rct->ymax) / 2.0f;
+}
 
-BLI_INLINE int   BLI_rcti_size_x(const struct rcti *rct) { return (rct->xmax - rct->xmin); }
-BLI_INLINE int   BLI_rcti_size_y(const struct rcti *rct) { return (rct->ymax - rct->ymin); }
-BLI_INLINE float BLI_rctf_size_x(const struct rctf *rct) { return (rct->xmax - rct->xmin); }
-BLI_INLINE float BLI_rctf_size_y(const struct rctf *rct) { return (rct->ymax - rct->ymin); }
+BLI_INLINE int BLI_rcti_size_x(const struct rcti *rct)
+{
+  return (rct->xmax - rct->xmin);
+}
+BLI_INLINE int BLI_rcti_size_y(const struct rcti *rct)
+{
+  return (rct->ymax - rct->ymin);
+}
+BLI_INLINE float BLI_rctf_size_x(const struct rctf *rct)
+{
+  return (rct->xmax - rct->xmin);
+}
+BLI_INLINE float BLI_rctf_size_y(const struct rctf *rct)
+{
+  return (rct->ymax - rct->ymin);
+}
 
 #ifdef __cplusplus
 }
 #endif
 
-#endif  /* __BLI_RECT_H__ */
+#endif /* __BLI_RECT_H__ */
