@@ -1,6 +1,4 @@
 /*
- * Copyright 2011, Blender Foundation.
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -15,26 +13,25 @@
  * along with this program; if not, write to the Free Software Foundation,
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * Contributor: 
- *		Jeroen Bakker 
- *		Monique Dewanchand
+ * Copyright 2011, Blender Foundation.
  */
 
 #include "COM_SetAlphaNode.h"
 #include "COM_SetAlphaOperation.h"
 #include "COM_ExecutionSystem.h"
 
-void SetAlphaNode::convertToOperations(NodeConverter &converter, const CompositorContext &/*context*/) const
+void SetAlphaNode::convertToOperations(NodeConverter &converter,
+                                       const CompositorContext & /*context*/) const
 {
-	SetAlphaOperation *operation = new SetAlphaOperation();
-	
-	if (!this->getInputSocket(0)->isLinked() && this->getInputSocket(1)->isLinked()) {
-		operation->setResolutionInputSocketIndex(1);
-	}
-	
-	converter.addOperation(operation);
-	
-	converter.mapInputSocket(getInputSocket(0), operation->getInputSocket(0));
-	converter.mapInputSocket(getInputSocket(1), operation->getInputSocket(1));
-	converter.mapOutputSocket(getOutputSocket(0), operation->getOutputSocket());
+  SetAlphaOperation *operation = new SetAlphaOperation();
+
+  if (!this->getInputSocket(0)->isLinked() && this->getInputSocket(1)->isLinked()) {
+    operation->setResolutionInputSocketIndex(1);
+  }
+
+  converter.addOperation(operation);
+
+  converter.mapInputSocket(getInputSocket(0), operation->getInputSocket(0));
+  converter.mapInputSocket(getInputSocket(1), operation->getInputSocket(1));
+  converter.mapOutputSocket(getOutputSocket(0), operation->getOutputSocket());
 }
