@@ -1,6 +1,4 @@
 /*
- * Copyright 2011, Blender Foundation.
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -15,35 +13,35 @@
  * along with this program; if not, write to the Free Software Foundation,
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * Contributor:
- *		Jeroen Bakker
- *		Monique Dewanchand
+ * Copyright 2011, Blender Foundation.
  */
 
 #include "COM_PixelateOperation.h"
 
 PixelateOperation::PixelateOperation(DataType datatype) : NodeOperation()
 {
-	this->addInputSocket(datatype);
-	this->addOutputSocket(datatype);
-	this->setResolutionInputSocketIndex(0);
-	this->m_inputOperation = NULL;
+  this->addInputSocket(datatype);
+  this->addOutputSocket(datatype);
+  this->setResolutionInputSocketIndex(0);
+  this->m_inputOperation = NULL;
 }
 
 void PixelateOperation::initExecution()
 {
-	this->m_inputOperation = this->getInputSocketReader(0);
+  this->m_inputOperation = this->getInputSocketReader(0);
 }
 
 void PixelateOperation::deinitExecution()
 {
-	this->m_inputOperation = NULL;
+  this->m_inputOperation = NULL;
 }
 
-void PixelateOperation::executePixelSampled(float output[4], float x, float y, PixelSampler sampler)
+void PixelateOperation::executePixelSampled(float output[4],
+                                            float x,
+                                            float y,
+                                            PixelSampler sampler)
 {
-	float nx = round(x);
-	float ny = round(y);
-	this->m_inputOperation->readSampled(output, nx, ny, sampler);
+  float nx = round(x);
+  float ny = round(y);
+  this->m_inputOperation->readSampled(output, nx, ny, sampler);
 }
-
