@@ -1,6 +1,4 @@
 /*
- * Copyright 2011, Blender Foundation.
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -15,9 +13,7 @@
  * along with this program; if not, write to the Free Software Foundation,
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * Contributor: 
- *		Jeroen Bakker 
- *		Monique Dewanchand
+ * Copyright 2011, Blender Foundation.
  */
 
 #include "COM_VectorCurveOperation.h"
@@ -25,36 +21,38 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-#  include "BKE_colortools.h"
+#include "BKE_colortools.h"
 #ifdef __cplusplus
 }
 #endif
 
 VectorCurveOperation::VectorCurveOperation() : CurveBaseOperation()
 {
-	this->addInputSocket(COM_DT_VECTOR);
-	this->addOutputSocket(COM_DT_VECTOR);
+  this->addInputSocket(COM_DT_VECTOR);
+  this->addOutputSocket(COM_DT_VECTOR);
 
-	this->m_inputProgram = NULL;
+  this->m_inputProgram = NULL;
 }
 void VectorCurveOperation::initExecution()
 {
-	CurveBaseOperation::initExecution();
-	this->m_inputProgram = this->getInputSocketReader(0);
+  CurveBaseOperation::initExecution();
+  this->m_inputProgram = this->getInputSocketReader(0);
 }
 
-void VectorCurveOperation::executePixelSampled(float output[4], float x, float y, PixelSampler sampler)
+void VectorCurveOperation::executePixelSampled(float output[4],
+                                               float x,
+                                               float y,
+                                               PixelSampler sampler)
 {
-	float input[4];
+  float input[4];
 
+  this->m_inputProgram->readSampled(input, x, y, sampler);
 
-	this->m_inputProgram->readSampled(input, x, y, sampler);
-
-	curvemapping_evaluate_premulRGBF(this->m_curveMapping, output, input);
+  curvemapping_evaluate_premulRGBF(this->m_curveMapping, output, input);
 }
 
 void VectorCurveOperation::deinitExecution()
 {
-	CurveBaseOperation::deinitExecution();
-	this->m_inputProgram = NULL;
+  CurveBaseOperation::deinitExecution();
+  this->m_inputProgram = NULL;
 }
