@@ -1,6 +1,4 @@
 /*
- * ***** BEGIN GPL LICENSE BLOCK *****
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -17,65 +15,83 @@
  *
  * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
  * All rights reserved.
- *
- * The Original Code is: all of this file.
- *
- * Contributor(s): none yet.
- * 
- * ***** END GPL LICENSE BLOCK *****
  */
 
-/** \file UI_interface_icons.h
- *  \ingroup editorui
+/** \file
+ * \ingroup editorui
  */
 
 #ifndef __UI_INTERFACE_ICONS_H__
 #define __UI_INTERFACE_ICONS_H__
 
-struct bContext;
 struct ID;
-struct Scene;
-struct PreviewImage;
 struct PointerRNA;
+struct PreviewImage;
+struct Scene;
+struct bContext;
 
 enum eIconSizes;
 
 typedef struct IconFile {
-	struct IconFile *next, *prev;
-	char filename[256]; /* FILE_MAXFILE size */
-	int index;
+  struct IconFile *next, *prev;
+  char filename[256]; /* FILE_MAXFILE size */
+  int index;
 } IconFile;
 
 #define ICON_DEFAULT_HEIGHT 16
-#define ICON_DEFAULT_WIDTH  16
+#define ICON_DEFAULT_WIDTH 16
+
+#define ICON_DEFAULT_HEIGHT_TOOLBAR 32
 
 #define ICON_DEFAULT_HEIGHT_SCALE ((int)(UI_UNIT_Y * 0.8f))
-#define ICON_DEFAULT_WIDTH_SCALE  ((int)(UI_UNIT_X * 0.8f))
+#define ICON_DEFAULT_WIDTH_SCALE ((int)(UI_UNIT_X * 0.8f))
 
 #define PREVIEW_DEFAULT_HEIGHT 128
 
 /*
  * Resizable Icons for Blender
  */
-void UI_icons_init(int first_dyn_id);
+void UI_icons_init(void);
+void UI_icons_reload_internal_textures(void);
+
 int UI_icon_get_width(int icon_id);
 int UI_icon_get_height(int icon_id);
+bool UI_icon_get_theme_color(int icon_id, unsigned char color[4]);
 
-void UI_id_icon_render(
-        const struct bContext *C, struct Scene *scene, struct ID *id, const bool big, const bool use_job);
+void UI_id_icon_render(const struct bContext *C,
+                       struct Scene *scene,
+                       struct ID *id,
+                       const bool big,
+                       const bool use_job);
 int UI_preview_render_size(enum eIconSizes size);
 
 void UI_icon_draw(float x, float y, int icon_id);
-void UI_icon_draw_preview(float x, float y, int icon_id);
-void UI_icon_draw_preview_aspect(float x, float y, int icon_id, float aspect);
-void UI_icon_draw_preview_aspect_size(float x, float y, int icon_id, float aspect, float alpha, int size);
+void UI_icon_draw_alpha(float x, float y, int icon_id, float alpha);
+void UI_icon_draw_preview(float x, float y, int icon_id, float aspect, float alpha, int size);
+
+void UI_icon_draw_ex(float x,
+                     float y,
+                     int icon_id,
+                     float aspect,
+                     float alpha,
+                     float desaturate,
+                     const char mono_color[4],
+                     const bool mono_border);
+
+void UI_icon_draw_desaturate(float x,
+                             float y,
+                             int icon_id,
+                             float aspect,
+                             float alpha,
+                             float desaturate,
+                             const char mono_color[4]);
 
-void UI_icon_draw_aspect(float x, float y, int icon_id, float aspect, float alpha);
-void UI_icon_draw_aspect_color(float x, float y, int icon_id, float aspect, const float rgb[3]);
-void UI_icon_draw_size(float x, float y, int size, int icon_id, float alpha);
 void UI_icons_free(void);
 void UI_icons_free_drawinfo(void *drawinfo);
 
+void UI_icon_draw_cache_begin(void);
+void UI_icon_draw_cache_end(void);
+
 struct ListBase *UI_iconfile_list(void);
 int UI_iconfile_get_index(const char *filename);
 
