@@ -1,6 +1,4 @@
 /*
- * ***** BEGIN GPL LICENSE BLOCK *****
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -17,20 +15,12 @@
  *
  * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
  * All rights reserved.
- *
- * The Original Code is: all of this file.
- *
- * Contributor(s): none yet.
- *
- * ***** END GPL LICENSE BLOCK *****
- * 
  */
 
-/** \file blender/editors/space_file/fsmenu.h
- *  \ingroup spfile
+/** \file
+ * \ingroup spfile
  */
 
-
 #ifndef __FSMENU_H__
 #define __FSMENU_H__
 
@@ -45,39 +35,44 @@ struct FSMenuEntry;
 
 /** Inserts a new fsmenu entry with the given \a path.
  * Duplicate entries are not added.
- * \param flag Options for inserting the entry.
+ * \param flag: Options for inserting the entry.
  */
-void    fsmenu_insert_entry(struct FSMenu *fsmenu, enum FSMenuCategory category, const char *path, const char *name, const enum FSMenuInsert flag);
+void fsmenu_insert_entry(struct FSMenu *fsmenu,
+                         enum FSMenuCategory category,
+                         const char *path,
+                         const char *name,
+                         const enum FSMenuInsert flag);
 
 /** Refresh 'valid' status of given menu entry */
 void fsmenu_entry_refresh_valid(struct FSMenuEntry *fsentry);
 
 /** Return whether the entry was created by the user and can be saved and deleted */
-short   fsmenu_can_save(struct FSMenu *fsmenu, enum FSMenuCategory category, int index);
+short fsmenu_can_save(struct FSMenu *fsmenu, enum FSMenuCategory category, int index);
 
 /** Removes the fsmenu entry at the given \a index. */
-void    fsmenu_remove_entry(struct FSMenu *fsmenu, enum FSMenuCategory category, int index);
+void fsmenu_remove_entry(struct FSMenu *fsmenu, enum FSMenuCategory category, int index);
 
 /** saves the 'bookmarks' to the specified file */
-void    fsmenu_write_file(struct FSMenu *fsmenu, const char *filename);
-	
+void fsmenu_write_file(struct FSMenu *fsmenu, const char *filename);
+
 /** reads the 'bookmarks' from the specified file */
-void    fsmenu_read_bookmarks(struct FSMenu *fsmenu, const char *filename);
+void fsmenu_read_bookmarks(struct FSMenu *fsmenu, const char *filename);
 
 /** adds system specific directories */
-void    fsmenu_read_system(struct FSMenu *fsmenu, int read_bookmarks);
+void fsmenu_read_system(struct FSMenu *fsmenu, int read_bookmarks);
 
 /** Free's all the memory associated with the fsmenu */
-void    fsmenu_free(void);
+void fsmenu_free(void);
 
 /** Refresh system directory menu */
-void    fsmenu_refresh_system_category(struct FSMenu *fsmenu);
+void fsmenu_refresh_system_category(struct FSMenu *fsmenu);
 
 /** Refresh 'valid' status of all menu entries */
-void    fsmenu_refresh_bookmarks_status(struct FSMenu *fsmenu);
+void fsmenu_refresh_bookmarks_status(struct wmWindowManager *wm, struct FSMenu *fsmenu);
 
 /** Get active index based on given directory. */
-int     fsmenu_get_active_indices(struct FSMenu *fsmenu, enum FSMenuCategory category, const char *dir);
+int fsmenu_get_active_indices(struct FSMenu *fsmenu,
+                              enum FSMenuCategory category,
+                              const char *dir);
 
 #endif
-
