@@ -1,10 +1,8 @@
 /*
- * ***** BEGIN GPL LICENSE BLOCK *****
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version. 
+ * of the License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -17,15 +15,10 @@
  *
  * The Original Code is Copyright (C) 2009 Blender Foundation.
  * All rights reserved.
- *
- * 
- * Contributor(s): Blender Foundation
- *
- * ***** END GPL LICENSE BLOCK *****
  */
 
-/** \file blender/editors/space_text/text_intern.h
- *  \ingroup sptext
+/** \file
+ * \ingroup sptext
  */
 
 #ifndef __TEXT_INTERN_H__
@@ -34,11 +27,11 @@
 /* internal exports only */
 
 struct ARegion;
-struct bContext;
 struct ScrArea;
 struct SpaceText;
 struct Text;
 struct TextLine;
+struct bContext;
 struct wmOperatorType;
 
 /* text_draw.c */
@@ -51,23 +44,33 @@ void text_scroll_to_cursor(struct SpaceText *st, struct ARegion *ar, const bool
 void text_scroll_to_cursor__area(struct SpaceText *st, struct ScrArea *sa, const bool center);
 void text_update_cursor_moved(struct bContext *C);
 
-#define TXT_OFFSET			((int)(0.5f * U.widget_unit))
-#define TXT_SCROLL_WIDTH	U.widget_unit
-#define TXT_SCROLL_SPACE	((int)(0.1f * U.widget_unit))
-#define TXT_LINE_SPACING	((int)(0.3f * st->lheight_dpi)) /* space between lines */
-#define TEXTXLOC			(st->cwidth * st->linenrs_tot)
+#define TXT_OFFSET ((int)(0.5f * U.widget_unit))
+#define TXT_SCROLL_WIDTH U.widget_unit
+#define TXT_SCROLL_SPACE ((int)(0.1f * U.widget_unit))
+#define TXT_LINE_SPACING ((int)(0.3f * st->lheight_dpi)) /* space between lines */
+#define TEXTXLOC (st->cwidth * st->linenrs_tot)
 
-#define SUGG_LIST_SIZE	7
-#define SUGG_LIST_WIDTH	20
-#define DOC_WIDTH		40
-#define DOC_HEIGHT		10
+#define SUGG_LIST_SIZE 7
+#define SUGG_LIST_WIDTH 20
+#define DOC_WIDTH 40
+#define DOC_HEIGHT 10
 
-#define TOOL_SUGG_LIST	0x01
-#define TOOL_DOCUMENT	0x02
+#define TOOL_SUGG_LIST 0x01
+#define TOOL_DOCUMENT 0x02
 
 int wrap_width(const struct SpaceText *st, struct ARegion *ar);
-void wrap_offset(const struct SpaceText *st, struct ARegion *ar, struct TextLine *linein, int cursin, int *offl, int *offc);
-void wrap_offset_in_line(const struct SpaceText *st, struct ARegion *ar, struct TextLine *linep, int cursin, int *offl, int *offc);
+void wrap_offset(const struct SpaceText *st,
+                 struct ARegion *ar,
+                 struct TextLine *linein,
+                 int cursin,
+                 int *offl,
+                 int *offc);
+void wrap_offset_in_line(const struct SpaceText *st,
+                         struct ARegion *ar,
+                         struct TextLine *linep,
+                         int cursin,
+                         int *offl,
+                         int *offc);
 int text_get_char_pos(const struct SpaceText *st, const char *line, int cur);
 
 void text_drawcache_tag_update(struct SpaceText *st, int full);
@@ -77,12 +80,27 @@ int text_do_suggest_select(struct SpaceText *st, struct ARegion *ar);
 void text_pop_suggest_list(void);
 
 int text_get_visible_lines(const struct SpaceText *st, struct ARegion *ar, const char *str);
-int text_get_span_wrap(const struct SpaceText *st, struct ARegion *ar, struct TextLine *from, struct TextLine *to);
+int text_get_span_wrap(const struct SpaceText *st,
+                       struct ARegion *ar,
+                       struct TextLine *from,
+                       struct TextLine *to);
 int text_get_total_lines(struct SpaceText *st, struct ARegion *ar);
 
 /* text_ops.c */
-enum { LINE_BEGIN, LINE_END, FILE_TOP, FILE_BOTTOM, PREV_CHAR, NEXT_CHAR,
-       PREV_WORD, NEXT_WORD, PREV_LINE, NEXT_LINE, PREV_PAGE, NEXT_PAGE };
+enum {
+  LINE_BEGIN,
+  LINE_END,
+  FILE_TOP,
+  FILE_BOTTOM,
+  PREV_CHAR,
+  NEXT_CHAR,
+  PREV_WORD,
+  NEXT_WORD,
+  PREV_LINE,
+  NEXT_LINE,
+  PREV_PAGE,
+  NEXT_PAGE
+};
 enum { DEL_NEXT_CHAR, DEL_PREV_CHAR, DEL_NEXT_WORD, DEL_PREV_WORD };
 
 void TEXT_OT_new(struct wmOperatorType *ot);
@@ -127,8 +145,6 @@ void TEXT_OT_selection_set(struct wmOperatorType *ot);
 void TEXT_OT_cursor_set(struct wmOperatorType *ot);
 void TEXT_OT_line_number(struct wmOperatorType *ot);
 
-void TEXT_OT_properties(struct wmOperatorType *ot);
-
 /* find = find indicated text */
 void TEXT_OT_find(struct wmOperatorType *ot);
 void TEXT_OT_find_set_selected(struct wmOperatorType *ot);
@@ -142,7 +158,7 @@ void TEXT_OT_to_3d_object(struct wmOperatorType *ot);
 
 void TEXT_OT_resolve_conflict(struct wmOperatorType *ot);
 
-int text_space_edit_poll(struct bContext *C);
+bool text_space_edit_poll(struct bContext *C);
 
 /* text_autocomplete.c */
 void TEXT_OT_autocomplete(struct wmOperatorType *ot);
@@ -151,4 +167,3 @@ void TEXT_OT_autocomplete(struct wmOperatorType *ot);
 extern const char *text_context_dir[]; /* doc access */
 
 #endif /* __TEXT_INTERN_H__ */
-
