@@ -1,6 +1,4 @@
 /*
- * ***** BEGIN GPL LICENSE BLOCK *****
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -17,21 +15,13 @@
  *
  * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
  * All rights reserved.
- *
- * The Original Code is: all of this file.
- *
- * Contributor(s): none yet.
- *
- * ***** END GPL LICENSE BLOCK *****
  * writeimage.c
- *
  */
 
-/** \file blender/imbuf/intern/writeimage.c
- *  \ingroup imbuf
+/** \file
+ * \ingroup imbuf
  */
 
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <errno.h>
@@ -46,56 +36,57 @@
 #include "IMB_colormanagement.h"
 #include "IMB_colormanagement_intern.h"
 
-static ImBuf *prepare_write_imbuf(const ImFileType *type, ImBuf *ibuf)
+static bool prepare_write_imbuf(const ImFileType *type, ImBuf *ibuf)
 {
-	return IMB_prepare_write_ImBuf((type->flag & IM_FTYPE_FLOAT), ibuf);
+  return IMB_prepare_write_ImBuf((type->flag & IM_FTYPE_FLOAT), ibuf);
 }
 
 short IMB_saveiff(struct ImBuf *ibuf, const char *name, int flags)
 {
-	const ImFileType *type;
+  const ImFileType *type;
 
-	errno = 0;
+  errno = 0;
 
-	BLI_assert(!BLI_path_is_rel(name));
+  BLI_assert(!BLI_path_is_rel(name));
 
-	if (ibuf == NULL) return (false);
-	ibuf->flags = flags;
+  if (ibuf == NULL) {
+    return (false);
+  }
+  ibuf->flags = flags;
 
-	for (type = IMB_FILE_TYPES; type < IMB_FILE_TYPES_LAST; type++) {
-		if (type->save && type->ftype(type, ibuf)) {
-			ImBuf *write_ibuf;
-			short result = false;
+  for (type = IMB_FILE_TYPES; type < IMB_FILE_TYPES_LAST; type++) {
+    if (type->save && type->ftype(type, ibuf)) {
+      short result = false;
 
-			write_ibuf = prepare_write_imbuf(type, ibuf);
+      prepare_write_imbuf(type, ibuf);
 
-			result = type->save(write_ibuf, name, flags);
+      result = type->save(ibuf, name, flags);
 
-			if (write_ibuf != ibuf)
-				IMB_freeImBuf(write_ibuf);
+      return result;
+    }
+  }
 
-			return result;
-		}
-	}
+  fprintf(stderr, "Couldn't save picture.\n");
 
-	fprintf(stderr, "Couldn't save picture.\n");
-
-	return false;
+  return false;
 }
 
-ImBuf *IMB_prepare_write_ImBuf(const bool isfloat, ImBuf *ibuf)
+bool IMB_prepare_write_ImBuf(const bool isfloat, ImBuf *ibuf)
 {
-	ImBuf *write_ibuf = ibuf;
+  bool changed = false;
 
-	if (isfloat) {
-		/* pass */
-	}
-	else {
-		if (ibuf->rect == NULL && ibuf->rect_float) {
-			ibuf->rect_colorspace = colormanage_colorspace_get_roled(COLOR_ROLE_DEFAULT_BYTE);
-			IMB_rect_from_float(ibuf);
-		}
-	}
+  if (isfloat) {
+    /* pass */
+  }
+  else {
+    if (ibuf->rect == NULL && ibuf->rect_float) {
+      ibuf->rect_colorspace = colormanage_colorspace_get_roled(COLOR_ROLE_DEFAULT_BYTE);
+      IMB_rect_from_float(ibuf);
+      if (ibuf->rect != NULL) {
+        changed = true;
+      }
+    }
+  }
 
-	return write_ibuf;
+  return changed;
 }
