@@ -1,6 +1,4 @@
 /*
- * ***** BEGIN GPL LICENSE BLOCK *****
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -17,16 +15,10 @@
  *
  * The Original Code is Copyright (C) 2005 Blender Foundation.
  * All rights reserved.
- *
- * The Original Code is: all of this file.
- *
- * Contributor(s): Bob Holcomb.
- *
- * ***** END GPL LICENSE BLOCK *****
  */
 
-/** \file NOD_composite.h
- *  \ingroup nodes
+/** \file
+ * \ingroup nodes
  */
 
 #ifndef __NOD_COMPOSITE_H__
@@ -36,7 +28,6 @@
 
 extern struct bNodeTreeType *ntreeType_Composite;
 
-
 /* ****************** types array for all composite nodes ****************** */
 
 void register_node_tree_type_cmp(void);
@@ -109,6 +100,7 @@ void register_node_type_cmp_luma_matte(void);
 void register_node_type_cmp_doubleedgemask(void);
 void register_node_type_cmp_keyingscreen(void);
 void register_node_type_cmp_keying(void);
+void register_node_type_cmp_cryptomatte(void);
 
 void register_node_type_cmp_translate(void);
 void register_node_type_cmp_rotate(void);
@@ -140,7 +132,14 @@ void register_node_type_cmp_planetrackdeform(void);
 void register_node_type_cmp_cornerpin(void);
 
 void node_cmp_rlayers_outputs(struct bNodeTree *ntree, struct bNode *node);
-void node_cmp_rlayers_register_pass(struct bNodeTree *ntree, struct bNode *node, struct Scene *scene, struct SceneRenderLayer *srl, const char *name, int type);
+void node_cmp_rlayers_register_pass(struct bNodeTree *ntree,
+                                    struct bNode *node,
+                                    struct Scene *scene,
+                                    struct ViewLayer *view_layer,
+                                    const char *name,
+                                    int type);
 const char *node_cmp_rlayers_sock_to_pass(int sock_index);
 
+void register_node_type_cmp_custom_group(bNodeType *ntype);
+
 #endif
