@@ -1,6 +1,4 @@
 /*
- * ***** BEGIN GPL LICENSE BLOCK *****
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -14,14 +12,10 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation,
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- *
- * Contributor(s): Willian P. Germano
- *
- * ***** END GPL LICENSE BLOCK *****
  */
 
-/** \file blender/python/generic/bgl.h
- *  \ingroup pygen
+/** \file
+ * \ingroup pygen
  */
 
 #ifndef __BGL_H__
@@ -39,22 +33,21 @@ int BGL_typeSize(int type);
  * For Python access to OpenGL functions requiring a pointer.
  */
 typedef struct _Buffer {
-	PyObject_VAR_HEAD 
-	PyObject *parent;
+  PyObject_VAR_HEAD PyObject *parent;
 
-	int type;		/* GL_BYTE, GL_SHORT, GL_INT, GL_FLOAT */
-	int ndimensions;
-	int *dimensions;
+  int type; /* GL_BYTE, GL_SHORT, GL_INT, GL_FLOAT */
+  int ndimensions;
+  int *dimensions;
 
-	union {
-		char *asbyte;
-		short *asshort;
-		int *asint;
-		float *asfloat;
-		double *asdouble;
+  union {
+    char *asbyte;
+    short *asshort;
+    int *asint;
+    float *asfloat;
+    double *asdouble;
 
-		void *asvoid;
-	} buf;
+    void *asvoid;
+  } buf;
 } Buffer;
 
 /** The type object */
