@@ -1,6 +1,4 @@
 /*
- * ***** BEGIN GPL LICENSE BLOCK *****
- *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -17,16 +15,10 @@
  *
  * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
  * All rights reserved.
- *
- * The Original Code is: all of this file.
- *
- * Contributor(s): none yet.
- *
- * ***** END GPL LICENSE BLOCK *****
  */
 
-/** \file blender/windowmanager/wm_cursors.h
- *  \ingroup wm
+/** \file
+ * \ingroup wm
  */
 
 #ifndef __WM_CURSORS_H__
@@ -38,81 +30,74 @@ void wm_init_cursor_data(void);
 
 /* old cursors */
 enum {
-	CURSOR_FACESEL = BC_GHOST_CURSORS,
-	CURSOR_WAIT, 
-	CURSOR_EDIT, 
-	CURSOR_X_MOVE, 
-	CURSOR_Y_MOVE, 
-	CURSOR_HELP, 
-	CURSOR_STD, 
-	CURSOR_NONE,
-	CURSOR_PENCIL,
-	CURSOR_COPY
+  CURSOR_FACESEL = BC_GHOST_CURSORS,
+  CURSOR_WAIT,
+  CURSOR_EDIT,
+  CURSOR_X_MOVE,
+  CURSOR_Y_MOVE,
+  CURSOR_HELP,
+  CURSOR_STD,
+  CURSOR_NONE,
+  CURSOR_PENCIL,
+  CURSOR_COPY,
 };
 
-
-//typedef struct BCursor_s BCursor;
+// typedef struct BCursor_s BCursor;
 typedef struct BCursor {
 
-	char *small_bm;
-	char *small_mask;
+  char *small_bm;
+  char *small_mask;
 
-	char small_sizex; 
-	char small_sizey; 
-	char small_hotx; 
-	char small_hoty; 
+  char small_sizex;
+  char small_sizey;
+  char small_hotx;
+  char small_hoty;
 
-	char *big_bm; 
-	char *big_mask;
+  char *big_bm;
+  char *big_mask;
 
-	char big_sizex; 
-	char big_sizey; 
-	char big_hotx; 
-	char big_hoty; 
+  char big_sizex;
+  char big_sizey;
+  char big_hotx;
+  char big_hoty;
 
-	char fg_color; 
-	char bg_color; 
+  bool can_invert_color;
 
 } BCursor;
 
 #define SYSCURSOR 1
 enum {
-	BC_NW_ARROWCURSOR = 2,
-	BC_NS_ARROWCURSOR,
-	BC_EW_ARROWCURSOR,
-	BC_WAITCURSOR,
-	BC_CROSSCURSOR,
-	BC_EDITCROSSCURSOR,
-	BC_BOXSELCURSOR,
-	BC_KNIFECURSOR,
-	BC_VLOOPCURSOR,
-	BC_TEXTEDITCURSOR,
-	BC_PAINTBRUSHCURSOR,
-	BC_HANDCURSOR,
-	BC_NSEW_SCROLLCURSOR,
-	BC_NS_SCROLLCURSOR,
-	BC_EW_SCROLLCURSOR,
-	BC_EYEDROPPER_CURSOR,
-	BC_SWAPAREA_CURSOR,
-/* --- ALWAYS LAST ----- */
-	BC_NUMCURSORS,
+  BC_NW_ARROWCURSOR = 2,
+  BC_NS_ARROWCURSOR,
+  BC_EW_ARROWCURSOR,
+  BC_WAITCURSOR,
+  BC_CROSSCURSOR,
+  BC_EDITCROSSCURSOR,
+  BC_BOXSELCURSOR,
+  BC_KNIFECURSOR,
+  BC_VLOOPCURSOR,
+  BC_TEXTEDITCURSOR,
+  BC_PAINTBRUSHCURSOR,
+  BC_HANDCURSOR,
+  BC_NSEW_SCROLLCURSOR,
+  BC_NS_SCROLLCURSOR,
+  BC_EW_SCROLLCURSOR,
+  BC_EYEDROPPER_CURSOR,
+  BC_SWAPAREA_CURSOR,
+  BC_H_SPLITCURSOR,
+  BC_V_SPLITCURSOR,
+  BC_N_ARROWCURSOR,
+  BC_S_ARROWCURSOR,
+  BC_E_ARROWCURSOR,
+  BC_W_ARROWCURSOR,
+  BC_STOPCURSOR,
+  /* --- ALWAYS LAST ----- */
+  BC_NUMCURSORS,
 };
 
-
-enum {
-	BC_BLACK = 0,
-	BC_WHITE, 
-	BC_RED,
-	BC_BLUE,
-	BC_GREEN,
-	BC_YELLOW
-};
-
-struct wmWindow;
 struct wmEvent;
+struct wmWindow;
 
 bool wm_cursor_arrow_move(struct wmWindow *win, const struct wmEvent *event);
 
-
 #endif /* __WM_CURSORS_H__ */
-
