@@ -94,7 +94,7 @@ def words_from_text(text):
             return False
 
         # check for code in comments
-        for c in "<>{}[]():._0123456789\&*":
+        for c in r"<>{}[]():._0123456789\&*":
             if c in w:
                 return False
 
@@ -333,8 +333,9 @@ def spell_check_comments_recursive(dirpath):
         for dirpath, dirnames, filenames in os.walk(path):
             # skip '.git'
             dirnames[:] = [d for d in dirnames if not d.startswith(".")]
-
             for filename in filenames:
+                if filename.startswith("."):
+                    continue
                 filepath = join(dirpath, filename)
                 if filename_check is None or filename_check(filepath):
                     yield filepath
@@ -343,6 +344,7 @@ def spell_check_comments_recursive(dirpath):
         ext = splitext(filename)[1]
         return (ext in {
             ".c",
+            ".cc",
             ".inl",
             ".cpp",
             ".cxx",
