@@ -39,20 +39,24 @@ BLACKLIST = {
 
     # The unpacked wheel is only loaded when actually used, not directly on import:
     os.path.join("io_blend_utils", "blender_bam-unpacked.whl"),
-    }
+}
+
+for mod in addon_utils.modules():
+    if addon_utils.module_bl_info(mod)['blender'] < (2, 80, 0):
+        BLACKLIST.add(mod.__name__)
 
 # Some modules need to add to the `sys.path`.
 MODULE_SYS_PATHS = {
     # Runs in a Python subprocess, so its expected its basedir can be imported.
     "io_blend_utils.blendfile_pack": ".",
-    }
+}
 
 if not bpy.app.build_options.freestyle:
     BLACKLIST.add("render_freestyle_svg")
 
 BLACKLIST_DIRS = (
     os.path.join(bpy.utils.resource_path('USER'), "scripts"),
-    ) + tuple(addon_utils.paths()[1:])
+) + tuple(addon_utils.paths()[1:])
 
 
 def module_names_recursive(mod_dir, *, parent=None):
@@ -83,13 +87,6 @@ def module_names_all(mod_dir):
     yield from module_names_recursive(mod_dir)
 
 
-def addon_modules_sorted():
-    modules = addon_utils.modules({})
-    modules[:] = [mod for mod in modules if not mod.__file__.startswith(BLACKLIST_DIRS)]
-    modules.sort(key=lambda mod: mod.__name__)
-    return modules
-
-
 def source_list(path, filename_check=None):
     from os.path import join
     for dirpath, dirnames, filenames in os.walk(path):
@@ -102,26 +99,9 @@ def source_list(path, filename_check=None):
                 yield filepath
 
 
-def load_addons():
-    modules = addon_modules_sorted()
-    addons = bpy.context.user_preferences.addons
-
-    # first disable all
-    for mod_name in list(addons.keys()):
-        addon_utils.disable(mod_name, default_set=True)
-
-    assert(bool(addons) is False)
-
-    for mod in modules:
-        mod_name = mod.__name__
-        if mod_name in BLACKLIST:
-            continue
-        addon_utils.enable(mod_name, default_set=True)
-        if not (mod_name in addons):
-            raise Exception("'addon_utils.enable(%r)' call failed" % mod_name)
-
-
 def load_modules():
+    VERBOSE = os.environ.get("BLENDER_VERBOSE") is not None
+
     modules = []
     module_paths = []
 
@@ -160,6 +140,16 @@ def load_modules():
             module_names[mod] = mod_dir, mod_full
     del module_names
 
+    #
+    # test we tested all files except for presets and templates
+    ignore_paths = [
+        os.sep + "presets" + os.sep,
+        os.sep + "templates_osl" + os.sep,
+        os.sep + "templates_py" + os.sep,
+        os.sep + "bl_app_templates_system" + os.sep,
+    ] + ([(os.sep + f + os.sep) for f in BLACKLIST] +
+         [(os.sep + f + ".py") for f in BLACKLIST])
+
     #
     # now submodules
     for m in modules:
@@ -175,7 +165,7 @@ def load_modules():
                 sys.path.extend([
                     os.path.normpath(os.path.join(mod_dir, f))
                     for f in MODULE_SYS_PATHS.get(mod_name_full, ())
-                    ])
+                ])
 
                 try:
                     __import__(mod_name_full)
@@ -187,7 +177,7 @@ def load_modules():
                     assert(os.path.samefile(mod_imp.__file__, submod_full))
 
                     modules.append(mod_imp)
-                except Exception as e:
+                except Exception:
                     import traceback
                     # Module might fail to import, but we don't want whole test to fail here.
                     # Reasoning:
@@ -198,7 +188,14 @@ def load_modules():
                     #   import failure.
                     # - We want to catch all failures of this script instead of stopping on
                     #   a first big failure.
-                    traceback.print_exc()
+                    do_print = True
+                    if not VERBOSE:
+                        for ignore in ignore_paths:
+                            if ignore in submod_full:
+                                do_print = False
+                                break
+                    if do_print:
+                        traceback.print_exc()
 
     #
     # check which filepaths we didn't load
@@ -217,14 +214,6 @@ def load_modules():
     for f in loaded_files:
         source_files.remove(f)
 
-    #
-    # test we tested all files except for presets and templates
-    ignore_paths = [
-        os.sep + "presets" + os.sep,
-        os.sep + "templates" + os.sep,
-    ] + ([(os.sep + f + os.sep) for f in BLACKLIST] +
-         [(os.sep + f + ".py")  for f in BLACKLIST])
-
     for f in source_files:
         for ignore in ignore_paths:
             if ignore in f:
@@ -236,9 +225,9 @@ def load_modules():
 
 
 def main():
-    load_addons()
     load_modules()
 
+
 if __name__ == "__main__":
     # So a python error exits(1)
     try:
